package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.34.3 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.34.3) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````(`/@`!````MAY```````!``````````*"?````
M`````````$``.``(`$``'``;``8````$````0`````````!``$```````$``
M0```````P`$```````#``0````````@``````````P````0``````@``````
M```"0`````````)````````5`````````!4``````````0`````````!````
M!0````````````````!``````````$````````":`````````)H`````````
M$`````````$````&`````)H`````````JD````````"J0```````6`0`````
M```!!0`````````0`````````@````8`````F@````````"J0````````*I`
M`````````@`````````"````````"``````````$````!````!@"````````
M&`)````````8`D```````#@`````````.``````````$`````````%#E=&0$
M````%)D````````4F4```````!290```````[`````````#L``````````0`
M````````4>5T9`8`````````````````````````````````````````````
M````````````$``````````O;&EB97AE8R]L9"UE;&8N<V\N,@`````*````
M!`````$```!$<F%G;VY&;'D```"X*0D`"@````0````@````1')A9V]N1FQY
M`````````````````````````````````````````#T````2````````````
M`````````````$0````2`````````````````````````$L````2````````
M`````````````````%,````2`````````````````````````%L````2````
M`````````````````````'D````2`````````````````````````(,````2
M`````````````````````````)X````2`````````````````````````*0`
M```2`````````````````````````+8````2````````````````````````
M`,8````2`````````````````````````,\````2````````````````````
M`````-0````2`````````````````````````.(````2````````````````
M`````````.P````2`````````````````````````/H````2````````````
M``````````````\!```2`````````````````````````"(!```2````````
M`````````````````#$!```2`````````````````````````$D!```2````
M`````````````````````%@!```2`````````````````````````'`!```2
M`````````````````````````(L!```2`````````````````````````)(!
M```2`````````````````````````*$!```2````````````````````````
M`+0!```2`````````````````````````+L!```2````````````````````
M`````,<!```2`````````````````````````-P!```2````````````````
M`````````.@!```2`````````````````````````/@!```2````````````
M`````````````/\!```2``````````````````````````0"```2````````
M``````````````````L"```2`````````````````````````!,"```2````
M`````````````````````!@"```6`````````````````````````!X"```2
M`````````````````````````"4"```2`````````````````````````"H"
M```2`````````````````````````#`"```2````````````````````````
M`$8"```2`````````````````````````$X"```2````````````````````
M`````%4"```2`````````````````````````&\"```2````````````````
M`````````'<"```2`````````````````````````(`"```2````````````
M`````````````(@"```2`````````````````````````*H"```2````````
M`````````````````+$"```2`````````````````````````+8"```2````
M`````````````````````,H"```2`````````````````````````-`"```2
M`````````````````````````-D"```2`````````````````````````.D"
M```2`````````````````````````/<"```2````````````````````````
M``P#```2`````````````````````````%D#```2````````````````````
M`````(`#```2`````````````````````````*,#```2````````````````
M`````````+$#```2`````````````````````````,L#```@````````````
M`````````````.4#```@`````````````````````````(L#```2````,!I`
M``````````````````P$```1`!0`$*Y````````(`````````*@!```2``P`
M,#A```````!>`````````#D"```2``P`,"]```````"-!@````````<$```2
M``P`0!Q```````#J`0```````"8$```2``T`V%)``````````````````#L#
M```2``P`8"A```````#O`0```````$@#```2``P`4"A````````#````````
M`&H#```2``P`P#5```````!O`@````````$$```2``H`,!A`````````````
M``````8````0`!$`6*Y```````````````````$````0`!$``:]`````````
M`````````*L````2``P`$$]```````"@`0```````%T"```2``P`<"Y`````
M``"Q`````````.\"```2``P`D"Q```````"K`````````/X"```2``P`,"Q`
M``````!9`````````"X#```2``P`4"I````````B`````````)L#```2``P`
MT"=````````J`````````%\!```2````D!M``````````````````"(#```2
M``P`@"I```````!$`````````!(````0`!$`6*Y```````````````````4!
M```1`!0`,*Y````````(`````````'@!```2````@!M`````````````````
M`!\$```2``P`MAY```````!-`0```````+T````2``P`L$Y```````!4````
M`````,`#```1`!@`X*Y````````$`````````!<$```1`!@`8*Y````````(
M`````````(\"```2``P`4"Y````````=`````````-\"```1`!@`Z*Y`````
M```(`````````)0````2``P`L%!```````#U`0```````#P!```1`!@``*]`
M```````!`````````!4#```2``P`T"I```````!<`0```````!D````1`!@`
MH*Y```````!```````````!?96YD`%]?8G-S7W-T87)T`%]E9&%T80!?7W-T
M86-K7V-H:U]G=6%R9`!$1C0P-"XP`&QI8F,N<V\N.`!M86QL;V,`<W1R;&5N
M`&UE;6UO=F4`<W1R;F-M<`!?<G1L9%]C86QL7VEN:70`1$9P<FEV871E7S$N
M,`!?:6YI=%]T;',`7U]S=&%C:U]C:&M?9F%I;`!S:&%?9FEN86P`86)O<G0`
M;65M8W!Y`'-H85]U<&1A=&4`871E>&ET`'-H85]I;FET`'!E<FQ?<G5N`&5X
M:70`4&5R;%]S>7-?=&5R;0!P97)L7V9R964`<&5R;%]D97-T<G5C=`!P97)L
M7W!A<G-E`&UY7W!A<E]P;`!097)L7W-A9F5S>7-M86QL;V,`<&5R;%]C;VYS
M=')U8W0`<&5R;%]A;&QO8P!03%]D;U]U;F1U;7``<'1H<F5A9%]A=&9O<FL`
M<W1P8W!Y`%!E<FQ?871F;W)K7VQO8VL`<W1R<F-H<@!097)L7V%T9F]R:U]U
M;FQO8VL`<W1R9'5P`%!E<FQ?<WES7VEN:70S`'-T<G1O:P!P87)?8VQE86YU
M<`!S=')C;7``4&5R;%]M9U]S970`4&5R;%]C<F]A:U]N;V-O;G1E>'0`4&5R
M;%]G971?<W8`4&5R;%]G=E]F971C:'!V`&=E='!I9`!O<&5N`'-T<F-H<@!F
M<')I;G1F`'-T870`97)R;F\`=6YL:6YK`&9R964`;6MD:7(`8VQO<V5D:7(`
M<&%R7VUK=&UP9&ER`')E86QL;V,`<W1R<W1R`&]P96YD:7(`<&%R7W-E='5P
M7VQI8G!A=&@`<F5A9&1I<@!G971P=W5I9`!S<')I;G1F`&=E='5I9`!G971?
M=7-E<FYA;65?9G)O;5]G971P=W5I9`!M96UC:'(`<F5A9`!P=&AR96%D7V=E
M='-P96-I9FEC`&QS965K`'9F<')I;G1F`')M9&ER`%]?<W1D97)R<`!L<W1A
M=`!P87)?9&EE`&%C8V5S<P!P87)?96YV7V-L96%N`')E861L:6YK`'!A<E]I
M;FET7V5N=@!P87)?9&ER;F%M90!P87)?8F%S96YA;64`<&%R7V9I;F1P<F]G
M`'!A<E]C=7)R96YT7V5X96,`4&5R;%]N97=84U]F;&%G<P!84U]);G1E<FYA
M;'-?4$%27T)/3U0`4&5R;%]N97=84P!B;V]T7T1Y;F%,;V%D97(`>'-?:6YI
M=`!097)L7W-V7W-E='!V`%!E<FQ?<W9?<V5T<'9N`%!,7W1H<E]K97D`7TE4
M35]R96=I<W1E<E1-0VQO;F5486)L90!?251-7V1E<F5G:7-T97)434-L;VYE
M5&%B;&4`7VEN:70`;6%I;@!?7W!R;V=N86UE`&5N=FER;VX`7W-T87)T`%]F
M:6YI`&QI8G!E<FPN<V\N-2XS-`!L:6)P=&AR96%D+G-O+C``;&EB9&PN<V\N
M,`!L:6)M+G-O+C0`;&EB8W)Y<'0N<V\N-`!L:6)U=&EL+G-O+C0`+W5S<B]L
M:6(O9V-C.#`Z+W5S<B]L;V-A;"]L:6(O<&5R;#4O-2XS-"]M86-H+T-/4D4`
M`!$````_````!`````@````@'!``!4`$@"@`0`20A@&,PJ$!(DD`!!N(@CA!
MN@0""#\```!!````10```$D```!*````40```%(```!3````50```%8```!7
M````6````%H```!<````70````````!?````>O!*:[U0=IYNQ=\?SMY'+6I_
MFGSKT^\.(/_D#B[%F[;49-1\N8WQ#MEQ6!RZXY)\0OK7A_JA;&"83\.;L@&+
M;^)'Q@'#Y3\LA_F<@6>OS&9"1=7LB0=PT\G5LG$S8MOM%8PES%:DFY:GW:-K
M?JF<F^<5`X-K&IY0"HH05Z/@^TDA8F0'```"``(``@`"``,``P`"``(``@`"
M`````@````````````````````(``@`"``(````"``(````````````"``(`
M`@`"``(``@`"``(``@`"``(``@`"``(``@`"``(``@`"``(``@`"``(``@`"
M``(````````````````````!``$``0`!``$``0`!``$``0`!``$``0`!``$`
M`0`!``$````!``$``0````$``0`!``$``0`"``$``0`!``(``0`"`#,````0
M`````````%`WEP@```(`*P```!````"0M'X````#`&L``````````*Q`````
M```2````)```````````````X*Y````````%````6```````````````Z*Y`
M```````%````6P```````````````*]````````%````70``````````````
MH*Y````````%````7P``````````````(*Q````````'````"```````````
M````**Q````````'````!@``````````````,*Q````````'````!0``````
M````````.*Q````````'````"@``````````````0*Q````````'````#```
M````````````2*Q````````'````!```````````````4*Q````````'````
M!P``````````````6*Q````````'`````@``````````````8*Q````````'
M`````0``````````````:*Q````````'`````P``````````````<*Q`````
M```'````*0``````````````>*Q````````'````*P``````````````@*Q`
M```````'````+```````````````B*Q````````'````+@``````````````
MD*Q````````'````(P``````````````F*Q````````'````)0``````````
M````H*Q````````'````)@``````````````J*Q````````'````*```````
M````````L*Q````````'````-0``````````````N*Q````````'````-@``
M````````````P*Q````````'````-P``````````````R*Q````````'````
M.```````````````T*Q````````'````,```````````````V*Q````````'
M````,@``````````````X*Q````````'````/```````````````Z*Q`````
M```'````.P``````````````\*Q````````'````%0``````````````^*Q`
M```````'````%@```````````````*U````````'````%P``````````````
M"*U````````'````/P``````````````$*U````````'````(0``````````
M````&*U````````'````&0``````````````(*U````````'````&@``````
M````````**U````````'````-```````````````,*U````````'````,P``
M````````````.*U````````'````,0``````````````0*U````````'````
M+P``````````````2*U````````'````+0``````````````4*U````````'
M````*@``````````````6*U````````'````)P``````````````8*U`````
M```'````(@``````````````:*U````````'````(```````````````<*U`
M```````'````'P``````````````>*U````````'````'@``````````````
M@*U````````'````'0``````````````B*U````````'````'```````````
M````D*U````````'````&P``````````````F*U````````'````.@``````
M````````H*U````````'````.0``````````````J*U````````'````&```
M````````````L*U````````'````50``````````````N*U````````'````
M40``````````````P*U````````'````%```````````````R*U````````'
M````$P``````````````T*U````````'````$@``````````````V*U`````
M```'````$0``````````````X*U````````'````$```````````````Z*U`
M```````'````#P``````````````\*U````````'````#@``````````````
M^*U````````'````#0```````````````*Y````````'````"P``````````
M````"*Y````````'````"0``````````````2(/L".B)"```Z&<Z``!(@\0(
MPP````````````````#_-;J3``#_);R3``"0D)"0_R6ZDP``:`````#IX/__
M__\ELI,``&@!````Z=#_____):J3``!H`@```.G`_____R6BDP``:`,```#I
ML/____\EFI,``&@$````Z:#_____)9*3``!H!0```.F0_____R6*DP``:`8`
M``#I@/____\E@I,``&@'````Z7#_____)7J3``!H"````.E@_____R5RDP``
M:`D```#I4/____\E:I,``&@*````Z4#_____)6*3``!H"P```.DP_____R5:
MDP``:`P```#I(/____\E4I,``&@-````Z1#_____)4J3``!H#@```.D`____
M_R5"DP``:`\```#I\/[___\E.I,``&@0````Z>#^____)3*3``!H$0```.G0
M_O___R4JDP``:!(```#IP/[___\E(I,``&@3````Z;#^____)1J3``!H%```
M`.F@_O___R42DP``:!4```#ID/[___\E"I,``&@6````Z8#^____)0*3``!H
M%P```.EP_O___R7ZD@``:!@```#I8/[___\E\I(``&@9````Z5#^____)>J2
M``!H&@```.E`_O___R7BD@``:!L```#I,/[___\EVI(``&@<````Z2#^____
M)=*2``!H'0```.D0_O___R7*D@``:!X```#I`/[___\EPI(``&@?````Z?#]
M____);J2``!H(````.G@_?___R6RD@``:"$```#IT/W___\EJI(``&@B````
MZ<#]____):*2``!H(P```.FP_?___R6:D@``:"0```#IH/W___\EDI(``&@E
M````Z9#]____)8J2``!H)@```.F`_?___R6"D@``:"<```#I</W___\E>I(`
M`&@H````Z6#]____)7*2``!H*0```.E0_?___R5JD@``:"H```#I0/W___\E
M8I(``&@K````Z3#]____)5J2``!H+````.D@_?___R52D@``:"T```#I$/W_
M__\E2I(``&@N````Z0#]____)4*2``!H+P```.GP_/___R4ZD@``:#````#I
MX/S___\E,I(``&@Q````Z=#\____)2J2``!H,@```.G`_/___R4BD@``:#,`
M``#IL/S___\E&I(``&@T````Z:#\____)1*2``!H-0```.F0_/___R4*D@``
M:#8```#I@/S___\E`I(``&@W````Z7#\____)?J1``!H.````.E@_/___R7R
MD0``:#D```#I4/S___\EZI$``&@Z````Z4#\____)>*1``!H.P```.DP_/__
M_R7:D0``:#P```#I(/S___\ETI$``&@]````Z1#\__]32(/L,$B+!522``!(
MB40D*#'`B7PD'$B-?"0<2(ET)!!(C70D$$B)5"0(2(U4)`CH^_[__[J`&T``
MOY`;0`!(B=;H&?___X`]<I(```!U+^@;____2(D%])$``$B%P`^$=@$``$B)
MQ^@3____BSTMD@``Z!C]___&@/\(````BST;D@``Z`;]__^+/1"2``"`B+(#
M```"Z/3\__^`B+(#```!BT0D'(UX!(U8`TAC_TC!YP/HU_[__TB+?"001(M$
M)!Q(B05^D0``2(L72,=`".!40`!(QT`8XU1``$B)$$B+%0F1``!(B5`008/X
M`0^.VP```$B#QPA!@\`#O@0```!,BP](8]:#Q@%(@\<(3(D,T$$Y\'7J36/`
M2<'@`TK'!```````2(L](I$``$4QP$B)P8G:O@`H0`#H8/[__X7`=$M(BST%
MD0``Z&#^__](C70D)+^*4T``B<,QP.@]`P``2(7`=#5(BSWAD```Z$S^___H
M5_[__XG82(M,)"A(,PW9D```=5Q(@\0P6\-(BSVZD```Z$7^___KITB+/9R0
M``!(A?]T!^A"&@``Z[B_.%-``$B-="0DZ.$"``!(B<=(B05WD```2(7`=)KK
MV4&X(````.E$____OP$```#H>_K__^B6^O__N`````!(/0````!S.E5(B>5!
M5%.#/</AO_\E=2!(B<-,BR/_4Q!)B00D2(/#&$B!^P````!S"X-[""5TX^CT
M^?__6T%<7</#54B)Y5-(@^P(N`````!(+0````!(P?@#2(G#=1'H1#0``$B#
MQ`A;7<-(A=MT[TB#ZP%(BP3=`````$B#^`%VZ?_0Z^552(GE05=!5D%50513
M2(/L&$B)\TR++T6)[TR-=PA)8\5,C63'$$B#/7R/````=%=%A>U^%TB+1PA(
MA<!T#DB)!16/```/MA"$TG5/Z&GY___H=/G__[@`JD``2(7`=$U(B=_H<OG_
M_[@`JD``2(7`=$),B>),B?9$B>_H"OW__XG'Z&/Y__],B24<CP``ZZ!(@\`!
M#[80A-)TL8#Z+W7P2(U0`4B)%:^.``#KX^C"_O__Z[2_<AY``.@<^?__N```
M``!(+0````!(P?@#2(E%R'0LNP````#K"DB#PP%(.5W(=!M(BP3=`````$B#
M^`%VZ$R)XDR)]D2)___0Z]OH=OC__[@`````2"T`````2,'X`TB)1<@/A%7_
M__^[`````.L.2(/#`4@Y7<@/A$#___](BP3=`````$B#^`%VY$R)XDR)]D2)
M___0Z]>X6*Y``$@]6*Y``'07N`````!(A<!T#55(B>6_6*Y``/_07</#OEBN
M0`!(@>Y8KD``2,'^`TB)\$C!Z#](`<9(T?YT%[@`````2(7`=`U52(GEOUBN
M0`#_T%W#PX`]`HX```!U655(B>5!5%.[4*Y``$B!ZTBN0`!(P?L#2(/K`4&\
M2*Y``$B+!>"-``!(.=AS&TB#P`%(B070C0``0?\4Q$B+!<6-``!(.=ARY>A.
M____Q@6LC0```5M!7%W#PU5(B>7H7?___UW#9F9F9BX/'X0`````````````
M`$%7059!54%455-(@^P(2(7_#X2K````3(L]8HT``$V%_P^$FP````^V!X3`
M=`0\/75>13'D28L?2(7;=#E)B?5)B?Y-8^1,B?T/'X``````3(GB3(GV2(G?
MZ'+W__^%P'4'0H`\(SUT1TB#Q0A(BUT`2(7;==I(@\0(2(G86UU!7$%=05Y!
M7\,/'X0``````$F)_$F#Q`%!#[8$)(3`=`0\/77O02G\ZXP/'X``````3"G]
M2HU<(P%(P?T#08EM`.NT,=OKL&8N#Q^$``````!32(G[2(/L$$B+!>&,``!(
MB40D"#'`9BX/'X0``````#'`2(UT)`1(B=_H`?___TB%P'0N2&-4)`1(BP5P
MC```2(T$T$B+4`A(B1!(A=)TT$B#P`A(BU`(2(D02(72=?#KODB+1"0(2#,%
M@HP``'4&2(/$$%O#Z)7V__\/'T0``$%7059!54%454B)]5-(B?M(@^PH2(L%
M58P``$B)1"08,<`QP(`^/0^4P$@!Q4B)[^AK]O__2(UT)!1(B=])B<0QP.AI
M_O__2(7`#X0$`0``2(G'28G%Z$7V__],.>`/@]````!,8W0D%$G!Y@,/M@.$
MP`^$G`$``#P]#X24`0``2(G82(/``0^V$(32=`6`^CUU\$@IV$B82HU\(`),
M`S6,BP``Z`?V__])B09(A<`/A',!``!(BP5TBP``2&-4)!1(C4L!2(L4T`^V
M`X@"A,!T)#P]=0[K'@\?A```````A,!T$DB#P0$/MD'_2(/"`8@"/#UUZL8"
M/3'`#Q]$```/MDP%`(A,`@%(@\`!A,EU[S'`2(M<)!A(,QU1BP``#X4-`0``
M2(/$*%M=05Q!74%>05_#,<!F+@\?A```````#[94!0!!B%0%`$B#P`&$TG7N
MZ[U,BSW5B@``28,_``^$M@```$R)^#'2ZP</'T``1(GJ2(/`"$2-:@%(@S@`
M=>^-<@-(8_9(P>8#BP6WB@``A<!U6\<%J8H```$```!(B??H"?7__TB%P'1\
M36/%3(G^2(G'3HTTQ0````!,B40D"$R)\NCV]/__3(M$)`A(B05:B@``2(G!
M2L=$P0@`````1(EL)!3I@?[__P\?0`!,B?_HV/3__TB)P4B)!2Z*``!(A<!T
M(4UCQ4Z--,4`````Z\4QP.E]_O__OA````!%,>WI8____[C_____Z>'^___H
M6?3__V8/'X0``````$%505154TB![)@```!(BP4<B@``2(F$)(@````QP$B%
M_W0(@#\`2(G]=25(BX0DB````$@S!?:)```/A?P```!(@<28````6UU!7$%=
MPV:0Z$OT__])B<1(A<!TSDR)Y^A+]/__2(7`#X2R````2(U8$+_I4D``N0(`
M``!(B=[SI@^7P!P`A,!TT[_K4D``N0,```!(B=[SI@^7P!P`A,!TNTB)[^BV
M\___2(G?28G%Z*OS__]!C7P%`DAC_^BN\___2(G92(GJONY20`!)B<5(B<<Q
MP.CF\___3(GO2(GFZ.OS__],B>^#^/]T#P^W1"009B4`\&8]`$!T.>C?\___
M3(GOZ.?S__],B>?HG_/__TB%P`^%5/___V8/'T0``$R)Y^C8\___2(GOZ.#S
M___I]O[__^C&_O__Z\7H#_/__V9F+@\?A```````#Q]``%-(B?M(@>R0````
M2(L%SH@``$B)A"2(````,<!(B>;HK//__X7`=3@/MU0D$('B`/```('Z`$``
M`'0(@?H`H```=1^^`@```$B)W^B0\___A<`/E,`/ML#K"&8/'T0``#'`2(N,
M)(@```!(,PUOB```=0E(@<20````6\/H?_+__V9F+@\?A```````#Q]``$%5
MNO\#``!)B?5!5%5(B?V_]%)``%-(@>P8!```2(L%+(@``$B)A"0(!```,<!(
MB>;H*O/__X7`?FN-4/]$BR5,B```2&/:@#P<`'53A=)T6TB)VKXO````2(GG
MZ`_S__](A<!T1D2)Y^@2\___2(G92(GB2(GN2(G'Z!'S__](BX0D"`0``$@S
M!<*'``!U-$B!Q!@$``!;74%<05W#9I!(8]CKK$2+)>2'``!$B>?HS/+__TR)
MZDB)[DB)Q^C>\O__Z[OHI_'__P\?@`````!32(G^2('L$`0``$B+!6Z'``!(
MB80D"`0``#'`2(GC2(G?Z+GR__](@^@!2#G8=P[K$<8``$B#Z`%(.=AT!8`X
M+W3OOB\```!(B=_HH/+__TB%P'0P2#G8=R9(B=_HGO+__TB+E"0(!```2#,5
M#X<``'4U2('$$`0``%O##Q]``,8``.O52(N$)`@$``!(,P7LA@``=1)(@<00
M!```O^E20`!;Z5CR___H\_#__P\?`$B#[`B+/0:'``#H\?'__[EPDT``NC`:
M0`"^!U-``$B)QTB#Q`CI5O/__V8/'T0``$B#[`B+/=:&``#HP?'__TB)Q^BY
M____BSW#A@``Z*[Q__]!N.A20`!%,<FZP#5``$R)P;XC4T``2(G'2(/$".D<
M\___9F8N#Q^$``````"0,<##9F8N#Q^$``````!FD$%528G]OSA30`!!5%53
M2(GS2('LF`0``$B+!2&&``!(B80DB`0``#'`2(GFZ$_X__^^+P```$R)[TB)
MQ>B?\?__2(7`=#I,B>Z_05-``#'`Z'OY__],B>A(BY0DB`0``$@S%=F%```/
MA7T!``!(@<28!```6UU!7$%=PP\?1```2(G?Z#CQ__^^3E-``$B)Q^A;\?__
M2(G#2(7`=*F`.P`/A-L```!F+@\?A```````2(7M=!-(B=Y(B>_H0/'__X7`
M#X28````2(G?Z*#O__](C4P#_TF)Q$@YRW,C@#DO=`?K'(`Y+W4,Q@$`2(/I
M`4@YRW7O2(G?Z'/O__])B<1,B>_H:.___TF-1`0!2#W_`P``#X<M____OE)3
M0``QP$V)Z+E04T``2(V\)(````!(B=KHF.___TB)YDB-O"2`````Z)CO__^%
MP'44#[=$)!!F)0#P9CT`@'15#Q]$``"^3E-``#'_Z(3P__](B<-(A<`/A,[^
M__^`.P`/A2____](A>UT&;D"````O^E20`!(B>[SI@^7PH#:`(32=,%!O`$`
M``"[Z5)``.E1____D+X!````2(V\)(````#H?N___X7`=9I(C;0D@````+]!
M4T``Z/CW__](C;PD@````.C;[___Z6[^___H<>[__Y!3OB\```!(B?OHLN__
M_TB-4`%(A<!(#T7:2(G?6^FN[___9F8N#Q^$```````/'P!(A?]T*X`_`'0F
M4TB)^^@][O__2(/``4@]``0``'<A2(G?6^EX_/__#Q^$``````"_Z5)``.EF
M[___9@\?1```,<!;PV9F+@\?A```````D$B#[!B_65-``$B+!<"#``!(B40D
M"#'`Z,3V__\QP+]B4T``Z+CV__\QP+]J4T``Z*SV__\QP+]S4T``Z*#V__\Q
MP+]Z4T``Z)3V__\QP+^*4T``Z(CV__\QP+\X4T``Z'SV__\QP+^64T``Z'#V
M__\QP+^@4T``Z&3V__\QP+^J4T``Z%CV__\QP+]!4T``Z$SV__\QP$B-="0$
MO[130`#H:_7__TB%P'0/2(G&OZ!30``QP.BG]O__,<!(C70D!+_%4T``Z$;U
M__](A<!T#TB)QK_74T``,<#H@O;__S'`2(UT)`2_XE-``.@A]?__2(7`=#Q(
MB<:_.%-``#'`Z%WV__\QP+X#5$``OWI30`#H3/;__TB+1"0(2#,%L((``'4U
M2(/$&,-F#Q^$```````QP$B-="0$O_)30`#HS_3__TB%P'2]2(G&OY930``Q
MP.@+]O__ZZSHE.S__P\?0`!(@^P8OY930`!(BP5@@@``2(E$)`@QP$B-="0$
MZ(_T__](A<!T*@^V$(#Z,`^4P(32#Y3""="#\`$/ML!(BTPD"$@S#2B"``!U
M"DB#Q!C#D#'`Z^CH-^S__P\?@`````!(@>S8````2(ET)"A(B50D,$B)3"0X
M3(E$)$!,B4PD2(3`=#</*40D4`\I3"1@#RE4)'`/*9PD@`````\II"20````
M#RFL)*`````/*;0DL`````\IO"3`````2(L%KH$``$B)1"08,<!(B?Y(C80D
MX````$B+/=V!``!(B40D"$B)XDB-1"0@QP0D"````,=$)`0P````2(E$)!#H
M/^W__[__````Z&7K__\/'T0``$%4N@(````Q]D&)_%532('L$``!`$B+!42!
M``!(B80D"``!`#'`2(GEZ!+M__](@^@!2(G!2,'Y/TC!Z3!(C10(#[?22"G*
M2"G02(G##XB1````,=)(B=Y$B>?HX.S__TB#^/\/A(\```"Z"``!`$B)[D2)
MY^C6[/__@_C_=&Y(F$B#^`=V24B-1`7X2#GH<POK/4B#Z`%(.>AR-$B+#3V`
M``!(.0AUZT@IZ$@!V$B+M"0(``$`2#,UHX```'5&2('$$``!`%M=05S##Q]$
M``!(@>L```$`2('[``#__P^%;____TC'P/_____KP;\25$``,<#H5_[__[\%
M5$``,<#H2_[__^AVZO__9@\?1```2(/L".A'[/__B<?H4.S__TB%P'0#2(L`
M2(/$",,/'P!!5%5(B?V_'E1``%-(@^P02(L%&8```$B)1"0(,<!(C70D!.A(
M\O__2(GN2(7`=`B`.`!(B<-U*+\>5$``,<#H?//__TB+1"0(2#,%X'\``'5:
M2(/$$%M=05S##Q]$``!(B<?HZ.O__TB%P'772(GOZ.OI__](B=])B<3HX.G_
M_TF-?`0"Z.;I__^^4E-``$F)V$B)ZDF)Q$B)Q[E.4T``,<#H&>K__TR)YNN,
MZ)_I__]F9BX/'X0```````\?0`!!5D%528G]OSA30`!!5%532('L4`$``$B+
M!5)_``!(B80D2`$``#'`2(UT)!!(QX0DD````#I40`!(QX0DF````.E20`!(
MQX0DH`````````!(QX0DT````-=30`!(QX0DV````$!40`!(QX0DX````$=4
M0`!(QX0DZ````$]40`!(QX0D\````%140`!(QX0D^`````````!(QX0DL```
M`"Y40`!(QX0DN````%A40`!(QX0DP`````````#H[O#__TB%P'0)@#@`#X5@
M!```,<#H2?[__TB)PTB%P`^$W0,``$B)W^BUZ/__2(U\``'HN^C__X`[`$F)
MQ'0B3(GE#[832(GO,<"^851``$B#PP%(@\4"Z.;H__^`.P!UX4B-G"38````
MO]=30`#K$V:02(/#"$B+>_A(A?\/A',!``!(C70D$#'`Z&/P__](B<5(A<!T
MVX`X`'362(G'Z"[U__^%P'3*2(GOZ(+I__](B<-(A<`/A#H!``!F#Q]$``!(
MB=Z+%DB#Q@2-@O_^_O[WTB'0)8"`@(!TZ8G"P>H0J8"````/1,)(C58"2`]$
M\HG!`,%,B>%(@]X#2"G>BSE(@\$$C8?__O[^]]<A^"6`@("`=.F)PL'J$*F`
M@```#T3"2(U1`D@/1,J)P@#"2(/9`TPIX8VL#@0$``!(8^U(B>_HJN?__[YK
M5$``38GA2(G:2(G'28G&0;AF5$``,<"Y4%-``.C7Y___OL`!``!,B??H:NG_
M_X/X_W4>9$B+%"4`````2(L%A7H``$2+!`)!@_@1#X6U`@``2(UT)!!,B??H
M^N?__XG#A<`/A+````!)BU4`2(L]/7T``$R)\3'`OC!50``Q[>@DZ?__2(N,
M)$@!``!(,PW5?```2(GH#X78`P``2('$4`$``%M=05Q!74%>PS'M9BX/'X0`
M`````$ACQ4B+G,20````2(7;=$"`.P!T.TB)WX/%`>BP\___A<!TW$B)W^@$
MZ/__2(G#2(7`#X6(_O__2&/%2(N<Q)````!(A=MUR`\?A```````,=OI:?[_
M_V8/'X0```````^W1"0@9B4`\&8]`$`/A3W___]$BV0D).@SZ/__03G$#X4J
M____#[=$)"!F)?\!9CW``0^%%____TB)[^A/YO__2(UT)!"_=%1``$B)Q3'`
MZ#ON__](A<`/A/(!``!)BWT`2(G&Z*;U__])B<1(A<`/A-H!``!,B>?H`N;_
M_X/X`WX]2&/0OWE40`"Y!0```$F-=!3\\Z8/E\*`V@"$TG4?@_@$#X1R`@``
M@^@$2)A!@'P$_R\/A&$"```/'T0``#'`Z!GY__^%P'453(GG,?;HR^?__T&)
MQ(7`#X5Y`0``O@-40`"_EE-``#'`Z._N___HNN?__[E04T``3(GR2(GO08G`
M0;GH4D``OIU40``QP.C*Y?__ZTX/'X0``````&1(BQ0E`````$B+!8!X``"#
M/`(1=4+H=>?__TB#[`B#PP%,B?)HZ%)``$&)P$&)V;E04T``OJM40`!(B>\Q
MP.A\Y?__6%J^P`$``$B)[^@-Y___@_C_=*A,B??HD.7__TB)[K\X4T``,<#H
M4>[__TB)[^B)^O__Z=#]__\/'T``ORY40``Q[>L2#Q^``````$ACQ4B+O,2P
M````2(7_=')(C70D$#'`@\4!Z,'L__](A<!TW(`X`'372(G'Z._E__](B<-(
MA<!TQ^G5^___28M5`$B+/9]Z``!,B?$QP+[H5$``,>WHAN;__^E=_?__D$B)
MQTB)1"0(Z`/Z__](BT0D"$B)Q^BFY?__2(G%Z3K]__^_#0```+LS5$``Z$_D
M__])B<3IE/O__P\?@`````!-BV4`Z1W^__^)Q^B0^/__28G%2(7`#XAT_O__
M,=)(C7#V1(GGZ+;E__^Z!@```$B-M"0*`0``1(GGZ+'E__](@_@&#X7(````
MBP5Y7@``.80D"@$```^%-/[__P^W!6E>``!F.80D#@$```^%'_[__S'228UU
MSD2)Y^AAY?__NB@```!(C;0D$`$``$2)Y^A<Y?__2(/X*'5W0;GH4D``N5!3
M0`!,B?(QP$R-A"00`0``OHY40`!(B>_&A"0X`0```.C)X___Z5S^__]-BVT(
M387M#X27_?__3(GOZ$_C__](@_@##X:%_?__28UT!?R_?E1``+D%````\Z8/
ME\`<`(3`30]$Y>ED_?__Z`_C__^_@U1``#'`Z-/V__\/'P!54TB#[!B+/11Y
M``!(BP7->```2(E$)`@QP.CQX___BSW[>```2(G#Z./C__](C70D!+]Z4T``
M#[:3L````(B0L0```#'`Z-7J__](A<!T"8`X,0^$EP$``#'`Z+#T__^+/;IX
M``#HI>/__[D#````N@$```"^O%1``$B)Q^C.Y/__2(G#2(7`=#-(BT`0BSV,
M>```2(LHZ'3C__^ZOE1``$B)QTB)[NB$X___2(M#$$B+&/9##D`/A7,!``"+
M/5UX``#H2./__[D#````N@$```"^PU1``$B)Q^AQY/__2(G#2(7`=#U(C70D
M!+]!4T``,<#H*.K__TB)Q4B%P`^$_````$B+0Q"+/1)X``!(BQCH^N+__TB)
MZDB)WDB)Q^@,X___BSWV=P``Z.'B__^Z`0```+[%5$``2(G'Z!_D__^+/=EW
M``!(B</HP>+__[K:5$``2(G>2(G'Z-'B__^+/;MW``#HIN+__TB-="0$OSA3
M0`#&@+$`````,<#HGNG__TB)!3=W``!(A<!T-[[``0``2(G'Z'7C__^-4`&#
M^@%V"8/X$0^%GP```$B+1"0(2#,%*'<```^%K````$B#Q!A;7<-(BSW\=@``
MZ)_W__](B07H=@``2(7`=;&_B%5``.B)X___9@\?A```````@'@!``^$9O[_
M_^E:_O__D$B+!<%V``"+/1-W``!(BRA(BT,02(L8Z/3A__](B>Y(B=_H:>[_
M_^GX_O__#Q]``(L]ZG8``.C5X?__2(G>2(G'Z#KC___I<O[__XG!2(L%='8`
M`$B+%65V``"_L%5``$B+,#'`Z`;C___HD>#__Y!54TB)^TB#[`CH0O+__TB)
MQ^@*\O__2(G%,<#HX//__X7`=")(A=MT'8`[`'08OV940`"Y!````$B)[O.F
M#Y?`'`"$P'0*2(/$"%M=PP\?`$B#Q`A(B=];7>GBZ___9I!F#Q]$````````
M````````05=,C4\X059!54%455-(@>R8`@``2(L%Y'4``$B)A"2(`@``,<!(
MB>),C9*`````28G008L!28LQ28/`$$F#P0@/R(G`2(GQ28E`\$B)\$C!Z2!(
MP>@H2,'N."4`_P``2`GP2(G.2,'A"$C!YAB!X0``_P")]D@)\$@)R$F)0/A-
M.<)UKDB-L@`"```/'T``2(M":$@S0D!(@\((2#-""$@S0OA(C0P`2,'H'T@)
MR(/@_TB)0GA(.?)UU4R+%TB+7Q!(BW<@2(MO&$R)T$R)TDR+3PA(P>H;2,'@
M!4@)T`,$)(V4,)EY@EI(B=A(BW0D"$@QZ$PAR$B-M#69>8):2#'H1(TL`DR)
MRDR)R$C!Z`)(P>(>38GH2`G"2(G82<'H&XG12#'(3"'02#'82`'P3(GN2,'F
M!4P)QD2-)`9,B=9,B=!(P>8>2,'H`DV)XT@)\$B+="002<'K&T@QPD&)P$PA
MZDB-M#.9>8):2#'*2`'R3(GF2,'F!4P)WD2-'!9,B>Y)P>T"2(M4)!A(P>8>
M3`GN2(V4$9EY@EI,B=E(,?!!B?9,(>!,,<!(P>D;2`'03(G:2,'B!4@)RDR)
MX4G![`)(P>$>1(TL`DB)\$B+5"0@3`GA3(GN2#'(28V4$)EY@EI(P>X;08G,
M3"'83#'P2`'03(GJ2,'B!4@)\D2-!`),B=I)P>L"2(M$)"A(P>(>3(G&3`G:
M28V$!IEY@EI(P>X;2#'108G33"'I3#'A2`'!3(G`2,'@!4@)\$2--`A,B>A)
MP>T"2(M,)#!(P>`>3(GV3`GH28V,#)EY@EI(,<)!B<5,(<),,=I(`<I,B?%(
MP>$%2,'N&T@)\4R)QDG!Z`)(P>8>1(TD$4B+5"0X3`G&3(GA2#'P28V4$YEY
M@EI(P>D;08GP3"'P3#'H2`'03(GB2,'B!4@)RDR)\4G![@)(P>$>1(T<`DB)
M\$B+5"1`3`GQ3(G>2#'(28V4%9EY@EI(P>X;08G.3"'@3#'`2`'03(G:2,'B
M!4@)\D2-+`),B>))P>P"2(M$)$A(P>(>3(GN3`GB28V$`)EY@EI(P>X;2#'1
M08G43"'93#'Q2`'!3(GH2,'@!4@)\$2-!`A,B=A)P>L"2(M,)%!(P>`>3(G&
M3`G828V,#IEY@EI(P>X;2#'"08G#3"'J3#'B2`'*3(G!2,'A!4@)\4R)[DG!
M[0)(P>8>1(TT$4B+5"183`GN3(GQ2#'P28V4%)EY@EI(P>D;08GU3"'`3#'8
M2`'03(GR2,'B!4@)RDR)P4G!Z`)(P>$>1(TD`DB)\$B+5"1@3`G!3(GF2#'(
M28V4$YEY@EI(P>X;08G(3"'P3#'H2`'03(GB2,'B!4@)\D2-'`),B?)(BT0D
M:$C!XAY)P>X"3(G>3`GR28V$!9EY@EI(P>X;2#'108G63"'A3#'!2`'!3(G8
M2,'@!4@)\$2-+`A,B>!)P>P"2(M,)'!(P>`>3(GN3`G@28V,")EY@EI(P>X;
M2#'"08G$3"':3#'R2`'*3(GI2,'A!4@)\4R)WDG!ZP)(P>8>1(T$$4B+5"1X
M3`G>3(G!2#'P28V4%IEY@EI(P>D;08GS3"'H3#'@2`'03(G"2,'B!4@)RDR)
MZ4G![0)(P>$>1(TT`DB)\$B+E"2`````3`GI3(GV2#'(28V4%)EY@EI(P>X;
M08G-3"'`3#'82`'03(GR2,'B!4@)\D2-)`),B<))P>@"2(N$)(@```!(P>(>
M3(GF3`G"28V$`YEY@EI(P>X;2#'108G03"'Q3#'I2`'!3(G@2,'@!4@)\$B+
MM"20````1(T<"$R)\$G![@)(P>`>28VT-9EY@EI-B=U,"?!)P>T;2#'"B<%,
M(>),,<)(`?),B=Y(P>8%3`GNB?9(`?),B>9)P>P"2,'F'D&)U4P)YDR+I"28
M````2#'P3"'83XV$()EY@EI-B>Q(,<A)P>P;3`'`38GH2<'@!4T)X$6)P$P!
MP$V)V$G!ZP))P>`>08G$30G828GSB?9(`[0DJ````$TQPT0QVDR+G"2@````
M2HV,&:'KV6Y-B>-(`=%,B>))P>L;2,'B!4P)VHG22`'13(GJ2<'M`DC!XAY!
MB<M,">I-B<5%B<!,`X0DL````$DQU40QZ$V)W4B-M`:AZ]EN3(G82<'M&TC!
MX`5,">B)P$@!\$R)YDG![`)(P>8>08G%3`GF28G4B=)),?1$,>%-B>Q(`Y0D
MN````$V-A`BAZ]EN3(GI2<'L&TC!X05,">&)R4D!R$R)V4G!ZP)(P>$>18G$
M3`G928GSB?9(`[0DP````$DQRT0QV$V)XTB-E`*AZ]EN3(G@2<'K&TC!X`5,
M"=B)P$@!PDR)Z$G![0)(P>`>08G33`GH28G-B<E(`XPDR````$DQQ44QZ$V)
MW4Z-A`:AZ]EN3(G>2<'M&TC!Y@5,">Z)]DP!QDV)X$G![`))P>`>08GU30G@
M28G$B<!-,<1$,>)-B>Q(C8P1H>O9;DR)ZDC!X@5)P>P;2`.$)-````!,">*)
MTD@!T4R)VDG!ZP)(P>(>08G,3`G:38G#18G`3`.$)-@```!),=-$,=Y-B>-(
MC;0PH>O9;DR)X$G!ZQM(P>`%3`G8B<!(`?!,B>Y)P>T"2,'F'D&)PTP)[DF)
MU8G22`.4).````!),?5$,>E-B=U-C80(H>O9;DR)V4G![1M(P>$%3`GIB<E)
M`<A,B>%)P>P"2,'A'D6)Q4P)X4F)](GV23',1#'@38GL2(V4`J'KV6Y,B>A)
MP>P;2,'@!4P)X(G`2`'"3(G82<'K`D@#M"3H````2,'@'D&)U$P)V$F)RXG)
M2`.,)/````!),<-%,=A-B>-.C80&H>O9;DR)YDG!ZQM(P>8%3`G>B?9,`<9-
MB>A)P>T"2<'@'D&)\TT)Z$F)Q8G`2`.$)/@```!-,<5$,>I-B=U(C8P1H>O9
M;DR)VDG![1M(P>(%3`GJB=)(`=%,B>))P>P"2,'B'D&)S4P)XDV)Q$6)P$DQ
MU$0QYDV)[$B-M#"AZ]EN3(GH2<'L&TC!X`5,">")P$@!\$R)WDC!YAY)P>L"
M08G$3`.$)``!``!,"=Y)B=.)TD@#E"0(`0``23'S1#'938GC38V$"*'KV6Y,
MB>%)P>L;2,'A!4P)V8G)20'(3(GI2<'M`DC!X1Y%B<-,">E)B?6)]D@#M"00
M`0``23'-1#'H38G=2(V4`J'KV6Y,B=A)P>T;2,'@!4P)Z(G`2`'"3(G@2<'L
M`DC!X!Y!B=5,">!)B<R)R4DQQ$4QX$V)[$Z-A`:AZ]EN3(GN2<'L&TC!Y@5,
M">:)]DP!QDV)V$G!ZP))P>`>08GT30G828G#2`.,)!@!``")P$TQPT@#A"0@
M`0``1#':38GC2(V,$:'KV6Y,B>))P>L;2,'B!4P)VHG22`'13(GJ2<'M`DC!
MXAY!B<M,">I-B<5%B<!,`X0D*`$``$DQU40Q[DV)W4B-M#"AZ]EN3(G82<'M
M&TC!X`5,">B)P$@!\$R)YDG![`)(P>8>08G%3`GF28G4B=)(`Y0D,`$``$DQ
M]$0QX4V)[$V-A`BAZ]EN3(GI2<'L&TC!X05,">&)R4D!R$R)V4G!ZP)(P>$>
M18G$3`G928GSB?9),<M$,=A-B>-(`[0D.`$``$B-E`*AZ]EN3(G@2<'K&TC!
MX`5,"=A$C1P03(GH2<'M`DC!X!Y,">A)B<V)R4DQQ8G"13'H38G=3HV$!J'K
MV6Y,B=Y)P>T;2,'F!4P)[DR+K"1``0``1HTT!DV)X$G![`))P>`>30G@3`G`
M1(G&28G$2(G02"'P32'<20G$N-R\&X])`<5,`>E-B?5)`<Q,B?%)P>T;2,'A
M!4P)Z4F)]4$!S$R)V4G!ZP)(P>$>3`G908G+20G(32'P32'=30GH3(NL)$@!
M``!)`<5,`>I-B>5)`=!,B>))P>T;2,'B!4P)ZD:-+`),B?))P>X"2,'B'DP)
M\DV)WD&)T$@)T4TAQDPAX4P)\4R+M"10`0``20'&3`'V38GN2`'Q3(GN2<'N
M&TC!Y@5,"?9$C30.3(GF2<'L`DC!YAY,">9-B<2)\4@)\DDAS$PAZDP)XDR+
MI"18`0``20'$30'C38GT3`':38GS2<'C!4G![!M-">-%C20338GK2<'M`DG!
MXQY-">M)B<U$B=I,"=Y)(=5,(?9,">Y,BZPD8`$``$D!Q4T!Z$V)Y4P!QDV)
MX$G![1M)P>`%30GH18TL,$V)\$G![@))P>`>30GP28G61(G&30G#22'V32'C
M30GS3(NT)&@!``!)`<9,`?%-B>Y)`<M,B>E)P>X;2,'A!4P)\4:--!E,B>%)
MP>P"2,'A'DP)X4F)]$&)RTD)R$TAZ$TAW$T)X$R+I"1P`0``20'$3`'B38GT
M20'03(GR2<'L&TC!X@5,">)&C20"3(GJ2<'M`DC!XAY,">I-B=U!B=!("=%-
M(<5,(?%,">E,BZPD>`$``$D!Q4P![DV)Y4@!\4R)YDG![1M(P>8%3`GN1(TL
M#DR)]DG![@)(P>8>3`GV38G&B?%("?))(<Y,(>),"?),B[0D@`$``$D!QDT!
M\TV)[DP!VDV)ZTG!XP5)P>X;30GS18TT$TV)XTG![`))P>,>30GC28G,1(G:
M3`G>22'43"'N3`GF3(ND)(@!``!)`<1-`>!-B?1,`<9-B?!)P>P;2<'@!4T)
MX$6-)#!-B>A)P>T"2<'@'DT)Z$F)U42)QDT)PTDA]4TA\TT)ZTR+K"20`0``
M20'%3`'I38GE20'+3(GA2<'M&TC!X05,">E&C2P93(GQ2<'N`DC!X1Y,"?%)
MB?9)"<A!B<M-(=Y-(>!-"?!,B[0DF`$``$D!QDP!\DV)[DD!T$R)ZDG![AM(
MP>(%3`GR1HTT`DR)XDG![`)(P>(>3`GB38G<08G02`G132'$3"'I3`GA3(ND
M)*`!``!)`<1,`>9-B?1(`?%,B?9)P>P;2,'F!4P)YD2-)`Y,B>Y)P>T"2,'F
M'DP)[DV)Q8GQ2`GR22'-3"'R3`GJ3(NL)*@!``!)`<5-`>M-B>5,`=I-B>-)
MP>T;2<'C!4T)ZT6-+!--B?-)P>X"2<'C'DT)\TF)SD2)VDP)WDDAUDPAYDP)
M]DR+M"2P`0``20'&30'P38GN3`'&38GH2<'N&TG!X`5-"?!%C30P38G@2<'L
M`DG!X!Y-">!)B=1$B<9-"<-)(?1-(>M-">-,BZ0DN`$``$D!Q$P!X4V)]$D!
MRTR)\4G![!M(P>$%3`GA1HTD&4R)Z4G![0)(P>$>3`GI28GU08G+20G(32'P
M32'=30GH3(NL),`!``!)`<5,`>I-B>5)`=!,B>))P>T;2,'B!4P)ZD:-+`),
MB?))P>X"38G82,'B'DP)\D&)UD@)T4TA\$PAX4P)P4R+A"3(`0``20'`3`'&
M38GH2`'Q3(GN2<'H&TC!Y@5,"<9$C00.3(GF2<'L`DR)\4C!YAY,">9!B?1(
M"?),(>%,(>I("<I(BXPDT`$``$@!P4D!RTR)P4@#A"38`0``3`':38G#2,'A
M!4P!\$G!ZQM,"=F)R4@!RDR)Z4G![0)(P>$>08G33`GI38GE08G/2`G.32']
M3"'&3`GN38G=2`'P3(G>2<'M&TC!Y@5,">Z)]D@!\$R)QDG!Z`)(P>8>08G%
M20GPOM;!8LI,,<$QRDB+C"3@`0``2`'Q20',3(GI3`'B38GL2,'A!4G![!M,
M">&)R4@!RDR)V4C!X1Y)P>L"08G420G+3(G!38GF18G`3#'92<'N&S'(2(N,
M).@!``!(`?%)`<]*C0PX3(G@2,'@!4P)\(G`3(TT`4R)Z$G![0),B=E(P>`>
M18GW18G;20G%2(N$)/`!``!,,>E(`?`QRDR)^4P!P$C!Z1M(`<),B?A(P>`%
M2`G(2(N,)/@!``")P$@!PDR)X$@!\4G![`)(P>`>3`'938GK08G03`G@38G$
M18GM23'#2<'L&T4QWDZ-'#%,B<%(P>$%3`GAB<E)`<M,B?E)P>\"2,'A'D6)
MW$D)STB+C"0``@``2`'Q3`'I28G%B<!-,?U$,>I,C2P13(GB3(GA2,'I&TC!
MX@5("<I,B<%)P>@"B=)(P>$>20'52(N4)`@"``!,"<%-B?A),<A%B>Y%B?](
M`?)%,<-(`=!,B?).C0083(GP2,'J&TC!X`5("=!(B<J)R8G`20'`3(G@2<'L
M`DC!X!Y%B<-)"<1(BX0D$`(``$PQXD@!\$$QU4R)VDP!^$D!Q4R)V$C!X`5(
MP>H;2`G03(GR2<'N`HG`2,'B'DD!Q4B+A"08`@``3`GR18GO2`'P2`'(3(GA
M18GD2#'103'(3(GY20'`3(GX2,'I&TC!X`5("<B)P$D!P$R)V$G!ZP)(P>`>
M18G&20G#2(N$)"`"``!,B?%(P>D;2`'P3`'@28G4B=)-,=Q%,>5.C20H3(GP
M2,'@!4@)R$B+C"0H`@``B<!)`<1,B?A(`?%)P>\"2,'@'D@!RDR)V46)Y4P)
M^$6)VT@QP4$QR$R)Z4D!T$R)ZDC!Z1M(P>(%2`G*B=))`=!,B?))P>X"2,'B
M'D6)QTD)UDB+E"0P`@``3(GY2,'I&T@!\DP!VDF)PXG`33'S13'<3HT<(DR)
M^DC!X@5("<I,B>E)P>T"B=)(P>$>20'32(N4)#@"``!,">E%B=Q(`?)(`=!,
MB?)%B?9(,<I!,=!,B>))`<!,B>!(P>H;2,'@!4@)T$B)RHG)B<!)`<!,B?A)
MP>\"2,'@'D6)Q4D)QTB+A"1``@``2`'P3#'Z3`'P03'33(GJ20'#3(GH2,'J
M&TC!X`5("=!,B>))P>P"B<!(P>(>20'#2(N$)$@"``!,">)%B=Y)B=1(`?!(
M`<A,B?E%B?](,=&)TD$QR$J-#`!,B?!-B?!)P>@;2,'@!4P)P(G`2`'!3(GH
M2<'M`DC!X!Y!B<A)"<5(BX0D4`(``$TQ[$@!\$4QXTV)Q$P!^$G![!M)`<-,
MB<!(P>`%3`G@B<!)`<-,B?!(P>`>2<'N`D6)W$P)\$R+M"18`@``20'V20'6
M3(GJ18GM2#'",=%)C10.3(GA38GF2<'N&TC!X05,"?&)R4@!RDR)P4G!Z`)(
MP>$>08G620G(2(N,)&`"``!(`?%,`>E)B<6)P$TQQ44QZTV)]4D!RTR)\4G!
M[1M(P>$%3`GIB<E)`<M,B>%)P>P"2,'A'D6)W4D)S$B+C"1H`@``2`'Q2`'(
M3(G!18G`3#'A,<I(C0P03(GH3(GJ2,'J&TC!X`5("=!,B?))P>X"2,'B'HG`
M20G62(N4)'`"``!(`<&)R$@!\DP!PDV)X$TQ\$4QPTF)P$P!VDF)PTG!X`5)
MP>L;30G828G#2,'H`DG!XQY!`=!,B>I)P>T"20G#2(N$)'@"``!(P>(>20G5
M1(GB00';2`'P1`'M3(E?$$@!PDR)\$B);QA,,>@QP4B-!`I,B<),B<%%`<A(
MP>(%2,'I&TR)1PA("<H!T$$!PD0#=R!,B1=,B7<@2(N$)(@"``!(,P4-8```
M=1)(@<28`@``6UU!7$%=05Y!7\/H%,K__P\?0`!(@^P(OX````#H(LK__[J)
MJ\WON?[<NIB^\.'2PTC'``$C16=(B5`(2(E($$C'0!AV5#(02(EP($C'0"@`
M````2,=`,`````#'0'@`````2(/$",-F9BX/'X0``````)!!5TACPD%628G&
M055!5$F)_%5)C6PD.%-(B?-(@^P(2(MW*$B+5S"-#,9(.?%(B4\H2(/2`$C!
MZ!U(`=!(B4<P2&-_>(7_=%9!O4````!(B=Y!*?U%.>Y%#T[N2`'O36/]3(GZ
MZ+?,__]!BT0D>$0!Z$&)1"1X@_A`=!5(@\0(6UU!7$%=05Y!7\-F#Q]$``!,
MB>=%*>Y,`?OH\NC__T&#_C\/CMP```!!@^Y`18GW0<'O!D6)_4F#Q0%)P>4&
M20'=\P]O`TR)YTB#PT`/$44`\P]O2]`/$4T0\P]O4^`/$54@\P]O6_`/$5TP
MZ*#H__],.>MUS$'!YP9%*?Y)8\9(@_@(<EM)BU4`28E4)#A)BU0%^$B)5`7X
M2(U5"$B#XOA(*=5)*>U(`<5(@^7X2(/]"'(82(/E^#'`28M,!0!(B0P"2(/`
M"$@YZ'+N18ET)'A(@\0(6UU!7$%=05Y!7\.0J`1U*$B%P'3B00^V50!!B%0D
M.*@"=-1!#[=4!?YFB50%_NO'28G=Z7#___]!BU4`08E4)#A!BU0%_(E4!?SK
MJT%63(UV.$%505152(G]4TB+1BA(B?-$BV8H1(MN,$C!Z`.#X#]!#\Q!#\V-
M2`%(F,9$!CB`2&/!3`'P@_DX#XX@`0``ND`````IRHG1=`\QTHG6@\(!Q@0P
M`#G*<O-(B=_HBN?__V8/[\`/$4,X2<=&,`````!!#Q%&$$$/$48@1(EK<$B)
MWT2)8W3H8.?__TB+`TB)WTC!Z!B(10!(BP-(P>@0B$4!2(L#2,'H"(A%`DB+
M`XA%`TB+0PA(P>@8B$4$2(M#"$C!Z!"(105(BT,(2,'H"(A%!DB+0PB(10=(
MBT,02,'H&(A%"$B+0Q!(P>@0B$4)2(M#$$C!Z`B(10I(BT,0B$4+2(M#&$C!
MZ!B(10Q(BT,82,'H$(A%#4B+0QA(P>@(B$4.2(M#&(A%#TB+0R!(P>@8B$40
M2(M#($C!Z!"(11%(BT,@2,'H"(A%$DB+0R!;B$4374%<05U!7NE,Q___NC@`
M```Q_RG*@_H(<R[VP@1U:X72#X0!____Q@``]L("#X3U_O__,<EFB4P0_NGI
M_O__9@\?A```````B=%(QP``````2,=$"/@`````2(U("$B#X?A(*<@!PH/B
M^(/Z"`^"M?[__X/B^#'`B<:#P`A(B3PQ.=!R\^F>_O__QP``````QT00_```
M``#IB_[__TB+!8Q;``!(@_C_="152(GE4TB#[`B[.*Y``/_02(/K"$B+`TB#
M^/]U\4B#Q`A;7</#`$B#[`CH?LW__TB#Q`C#````+@`N+@`E<R\E<P`O<')O
M8R]C=7)P<F]C+V9I;&4`1'EN84QO861E<CHZ8F]O=%]$>6YA3&]A9&5R`$EN
M=&5R;F%L<SHZ4$%2.CI"3T]4`%!!4E]414U0`%!!4E]04D]'3D%-10`Z`"\`
M)7,E<R5S`%!%4DPU3$E"`%!%4DQ,24(`4$523#5/4%0`4$523$E/`%!!4E])
M3DE424%,25I%1`!005)?4U!!5TY%1`!005)?0TQ%04X`4$%27T1%0E5'`%!!
M4E]#04-(10!005)?1TQ/0D%,7T1%0E5'`%!!4E]'3$]"04Q?5$U01$E2`%!!
M4E]435!$25(`4$%27T=,3T)!3%]414U0`%!!4E]'3$]"04Q?0TQ%04X`,0!L
M<V5E:R!F86EL960`<F5A9"!F86EL960`3$1?3$E"4D%265]0051(`%5315(`
M4UE35$5-`"]T;7`O`%1-4$1)4@!414U01$E2`%1%35``5$U0`%5315).04U%
M`"4P,G@`<&%R+0`E<R5S)7,E<P!0051(`'!A<FP`+G!A<@!S:&]R="!R96%D
M`"5S)7-C86-H92TE<R5S`"5S)7-T96UP+25U)7,`)7,E<W1E;7`M)74M)74E
M<P`8`'!E<FP`,`!005(Z.E!A8VME<CHZ5D524TE/3@`Q+C`U.0`M90`M+0``
M`"5S.B!C<F5A=&EO;B!O9B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!F86EL
M960@*&5R<FYO/25I*0H``````````````````"5S.B!P<FEV871E('-U8F1I
M<F5C=&]R>2`E<R!I<R!U;G-A9F4@*'!L96%S92!R96UO=F4@:70@86YD(')E
M=')Y('EO=7(@;W!E<F%T:6]N*0H```````!5;F%B;&4@=&\@8W)E871E(&-A
M8VAE(&1I<F5C=&]R>0``````````)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@
M8V%C:&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@``````
M````979A;"`G97AE8R`O=7-R+V)I;B]P97)L("`M4R`D,"`D>S$K(B1`(GTG
M"FEF(#`[(",@;F]T(')U;FYI;F<@=6YD97(@<V]M92!S:&5L;`IP86-K86=E
M(%]?<&%R7W!L.PIM>2`H)%!!4E]-04=)0RP@)$9)3$5?;V9F<V5T7W-I>F4L
M("1C86-H95]N86UE7W-I>F4I.PI"14=)3B!["B1005)?34%'24,@/2`B7&Y0
M05(N<&U<;B(["B1&24Q%7V]F9G-E=%]S:7IE(#T@-#L@("`C('!A8VLH(DXB
M*0HD8V%C:&5?;F%M95]S:7IE(#T@-#`["B102UI)4%]-04=)0R`](")02UPP
M,#-<,#`T(CL*?0IS=6(@9FEN9%]P87)?;6%G:6,*>PIM>2`H)&9H*2`]($!?
M.PIM>2`D8VAU;FM?<VEZ92`](#8T("H@,3`R-#L*;7D@)&)U9CL*;7D@)'-I
M>F4@/2`M<R`D9F@["FUY("1P;W,@/2`H)'-I>F4M,2D@+2`H)'-I>F4M,2D@
M)2`D8VAU;FM?<VEZ93L@("`@("`C($Y/5$4Z("1P;W,@:7,@82!M=6QT:7!L
M92!O9B`D8VAU;FM?<VEZ90IW:&EL92`H)'!O<R`^/2`P*2!["G-E96L@)&9H
M+"`D<&]S+"`P.PIR96%D("1F:"P@)&)U9BP@)&-H=6YK7W-I>F4@*R!L96YG
M=&@H)%!!4E]-04=)0RD["FEF("@H;7D@)&D@/2!R:6YD97@H)&)U9BP@)%!!
M4E]-04=)0RDI(#X](#`I('L*<F5T=7)N("1P;W,@*R`D:3L*?0HD<&]S("T]
M("1C:'5N:U]S:7IE.PI]"G)E='5R;B`M,3L*?0IM>2`H)'!A<E]T96UP+"`D
M<')O9VYA;64L($!T;7!F:6QE+"`E36]D=6QE0V%C:&4I.PI%3D0@>R!I9B`H
M)$5.5GM005)?0TQ%04Y]*2!["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER
M92!&:6QE.CI"87-E;F%M93L*<F5Q=6ER92!&:6QE.CI3<&5C.PIM>2`D=&]P
M9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A<E]T96UP*3L*;W5T
M<RAQ<5M296UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T96UP(ETI.PI&:6QE.CI&
M:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@<FUD:7(@.B!U;FQI;FL@
M?2P@)'!A<E]T96UP*3L*<FUD:7(@)'!A<E]T96UP.PII9B`H+60@)'!A<E]T
M96UP("8F("1>3R!N92`G35-7:6XS,B<I('L*;7D@)'1M<"`](&YE=R!&:6QE
M.CI496UP*`I414U03$%412`]/B`G=&UP6%A86%@G+`I$25(@/3X@1FEL93HZ
M0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL"E-51D9)6"`]/B`G+F-M9"<L
M"E5.3$E.2R`]/B`P+`HI.PIM>2`D9FEL96YA;64@/2`D=&UP+3YF:6QE;F%M
M93L*<')I;G0@)'1M<"`\/"(N+BXB.PIX/3$[('=H:6QE(%L@7"1X("UL="`Q
M,"!=.R!D;PIR;2`M<F8@)R1P87)?=&5M<"<*:68@6R!<(2`M9"`G)'!A<E]T
M96UP)R!=.R!T:&5N"F)R96%K"F9I"G-L965P(#$*>#U@97AP<B!<)'@@*R`Q
M8`ID;VYE"G)M("<D9FEL96YA;64G"BXN+@IC;&]S92`D=&UP.PIC:&UO9"`P
M-S`P+"`D9FEL96YA;64["FUY("1C;60@/2`B)&9I;&5N86UE(#XO9&5V+VYU
M;&P@,CXF,2`F(CL*<WES=&5M*"1C;60I.PIO=71S*'%Q6U-P87=N960@8F%C
M:V=R;W5N9"!P<F]C97-S('1O('!E<F9O<FT@8VQE86YU<#H@)&9I;&5N86UE
M72D["GT*?2!]"D)%1TE.('L*26YT97)N86QS.CI005(Z.D)/3U0H*2!I9B!D
M969I;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/5#L*979A;"!["E]P87)?:6YI
M=%]E;G8H*3L*;7D@)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@)7-Y
M<R`]("@*<&%T:%]S97`@("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z
M("<Z)RDL"E]E>&4@("`@("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\
M8WEG=VEN*2\@/R`G+F5X92<@.B`G)RDL"E]D96QI;2`@("`@(#T^("@D7D\@
M/7X@+UY-4U=I;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD["E]S971?<')O9VYA
M;64H*3L*;W5T<RAQ<5M<)'!R;V=N86UE(#T@(B1P<F]G;F%M92)=*3L*7W-E
M=%]P87)?=&5M<"@I.PIO=71S*'%Q6UPD14Y6>U!!4E]414U0?2`]("(D14Y6
M>U!!4E]414U0?2)=*3L*;7D@*"1S=&%R=%]P;W,L("1S=&%R=%]O9E]&24Q%
M7W-E8W1I;VXI.PI-04=)0SH@>PIL;V-A;"`D4TE'>U]?5T%23E]??2`]('-U
M8B![?3L*=6YL97-S("AO<&5N(%]&2"P@)SPZ<F%W)RP@)'!R;V=N86UE*2![
M"F]U=',H<7%;0V%N)W0@<F5A9"!F<F]M(&9I;&4@(B1P<F]G;F%M92)=*3L@
M(",@9&]N)W0@=7-E("0A(&AE<F4@87,@:70@<F5Q=6ER97,@17)R;F\N<&T*
M;&%S="!-04=)0SL*?0IM>2`D;6%G:6-?<&]S(#T@9FEN9%]P87)?;6%G:6,H
M*E]&2"D["FEF("@D;6%G:6-?<&]S(#P@,"D@>PIO=71S*'%Q6T-A;B=T(&9I
M;F0@;6%G:6,@<W1R:6YG("(D4$%27TU!1TE#(B!I;B!F:6QE("(D<')O9VYA
M;64B72D["FQA<W0@34%'24,["GT*;W5T<R@B1F]U;F0@4$%2(&UA9VEC(&%T
M('!O<VET:6]N("1M86=I8U]P;W,B*3L*<V5E:R!?1D@L("1M86=I8U]P;W,@
M+2`D1DE,15]O9F9S971?<VEZ92`M(&QE;F=T:"@B7#!#04-(12(I+"`P.PIR
M96%D(%]&2"P@)&)U9BP@;&5N9W1H*")<,$-!0TA%(BD["FEF("@D8G5F(&YE
M(")<,$-!0TA%(B`F)B`D8G5F(&YE(")<,$-,14%.(BD@>PIO=71S*").;R!C
M86-H92!M87)K97(@9F]U;F0B*3L*;&%S="!-04=)0SL*?0IO=71S*'%Q6T-A
M8VAE(&UA<FME<B`B)&)U9B(@9F]U;F1=*3L*<V5E:R!?1D@L("1M86=I8U]P
M;W,@+2`D1DE,15]O9F9S971?<VEZ92P@,#L*<F5A9"!?1D@L("1B=68L("1&
M24Q%7V]F9G-E=%]S:7IE.PIM>2`D;V9F<V5T(#T@=6YP86-K*").(BP@)&)U
M9BD["F]U=',H(D]F9G-E="!F<F]M('-T87)T(&]F($9)3$5S(&ES("1O9F9S
M970B*3L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`D1DE,15]O9F9S971?<VEZ
M92`M("1O9F9S970L(#`["B1S=&%R=%]O9E]&24Q%7W-E8W1I;VX@/2!T96QL
M(%]&2#L*;7D@)7)E<75I<F5?;&ES=#L*<F5A9"!?1D@L("1B=68L(#0[("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(R!R96%D('1H92!F:7)S="`B1DE,
M12(*=VAI;&4@*"1B=68@97$@(D9)3$4B*2!["G)E860@7T9(+"`D8G5F+"`T
M.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FUY("1F=6QL
M;F%M92`]("1B=68["F]U=',H<7%;56YP86-K:6YG($9)3$4@(B1F=6QL;F%M
M92(N+BY=*3L*;7D@)&-R8R`]("@@)&9U;&QN86UE(#U^('-\7BA;82UF7&1=
M>SA]*2]\?"`I(#\@)#$@.B!U;F1E9CL*;7D@*"1B87-E;F%M92P@)&5X="D@
M/2`H)&)U9B`]?B!M?"@_.BXJ+RD_*"XJ*2A<+BXJ*7PI.PIR96%D(%]&2"P@
M)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PII
M9B`H9&5F:6YE9"@D97AT*2!A;F0@)&5X="`A?B`O7"XH/SIP;7QP;'QI>'QA
M;"DD+VDI('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H(B1C<F,D97AT(BP@
M)&)U9BP@,#<U-2D["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9U;&QN86UE
M?2`]("1F:6QE;F%M93L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9FEL96YA
M;65](#T@)&9U;&QN86UE.PI]"F5L<V4@>PHD36]D=6QE0V%C:&5[)&9U;&QN
M86UE?2`]('L*8G5F(#T^("1B=68L"F-R8R`]/B`D8W)C+`IN86UE(#T^("1F
M=6QL;F%M92P*?3L*)')E<75I<F5?;&ES='LD9G5L;&YA;65]*RL["GT*<F5A
M9"!?1D@L("1B=68L(#0["GT*;&]C86P@0$E.0R`]("AS=6(@>PIM>2`H)'-E
M;&8L("1M;V1U;&4I(#T@0%\["G)E='5R;B!I9B!R968@)&UO9'5L92!O<B`A
M)&UO9'5L93L*;7D@)&EN9F\@/2`D36]D=6QE0V%C:&5[)&UO9'5L97T["G)E
M='5R;B!U;FQE<W,@)&EN9F\["F1E;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U
M;&5].PHD24Y#>R1M;V1U;&5](#T@(B]L;V%D97(O)&EN9F\O)&UO9'5L92([
M"FEF("@D14Y6>U!!4E]#3$5!3GT@86YD(&1E9FEN960H)DE/.CI&:6QE.CIN
M97<I*2!["FUY("1F:"`]($E/.CI&:6QE+3YN97=?=&UP9FEL92!O<B!D:64@
M(D-A;B=T(&-R96%T92!T96UP(&9I;&4Z("0A(CL*)&9H+3YB:6YM;V1E*"D[
M"B1F:"T^<')I;G0H)&EN9F\M/GMB=69]*3L*)&9H+3YS965K*#`L(#`I.PIR
M971U<FX@)&9H.PI]"F5L<V4@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B
M)&EN9F\M/GMC<F-]+G!M(BP@)&EN9F\M/GMB=69]*3L*)&EN9F\M/GMF:6QE
M?2`]("1F:6QE;F%M93L*;W!E;B!M>2`D9F@L("<\.G)A=R<L("1F:6QE;F%M
M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)&9I;&5N86UE(CH@)"%=.PIR971U
M<FX@)&9H.PI]"F1I92`B0F]O='-T<F%P<&EN9R!F86EL960Z(&-A;B=T(&9I
M;F0@;6]D=6QE("1M;V1U;&4A(CL*?2P@0$E.0RD["G)E<75I<F4@6%-,;V%D
M97(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!#87)P.CI(96%V>3L*
M<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y
M;F%L;V%D97(H*3L*<F5Q=6ER92!)3SHZ1FEL93L*=VAI;&4@*&UY("1F:6QE
M;F%M92`]("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI('L*=6YL97-S
M("@D24Y#>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^("]"4T1004XO*2![
M"FEF("@D9FEL96YA;64@/7X@+UPN<&UC/R0O:2D@>PIR97%U:7)E("1F:6QE
M;F%M93L*?0IE;'-E('L*9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL96YA;64@
M/7X@+W-I=&5C=7-T;VUI>F5<+G!L)"\["GT*?0ID96QE=&4@)')E<75I<F5?
M;&ES='LD9FEL96YA;65].PI]"FEF("@D8G5F(&YE("102UI)4%]-04=)0RD@
M>PIO=71S*'%Q6TYO('II<"!F;W5N9"!A9G1E<B!&24Q%('-E8W1I;VX@:6X@
M9FEL92`B)'!R;V=N86UE(ETI.PIL87-T($U!1TE#(#L*?0HD<W1A<G1?<&]S
M(#T@*'1E;&P@7T9(*2`M(#0[("`@("`@("`@("`@("`@(",@<W1A<G0@;V8@
M>FEP"GT*;7D@0'!A<E]A<F=S.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H
M+"`D8V%C:&5?;F%M92D["F1E;&5T92`D14Y6>U!!4E]!4%!?4D554T5].R`C
M('-A;FET:7IE("A2155312!M87D@8F4@82!S96-U<FET>2!P<F]B;&5M*0II
M9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS
M)R`F)B!S:&EF="DI('L*;7D@)61I<W1?8VUD(#T@<7<H"G`@("!B;&EB7W1O
M7W!A<@II("`@:6YS=&%L;%]P87(*=2`@('5N:6YS=&%L;%]P87(*<R`@('-I
M9VY?<&%R"G8@("!V97)I9GE?<&%R"BD["FEF("A`05)'5B!A;F0@)$%21U9;
M,%T@97$@)RTM<F5U<V4G*2!["G-H:69T($!!4D=6.PHD14Y6>U!!4E]!4%!?
M4D554T5](#T@<VAI9G0@0$%21U8["GT*96QS92![(",@;F]R;6%L('!A<FP@
M8F5H879I;W5R"FUY($!A9&1?=&]?:6YC.PIW:&EL92`H0$%21U8I('L*)$%2
M1U9;,%T@/7X@+UXM*%M!24U/0DQB<7!I=7-4=ETI*"XJ*2\@;W(@;&%S=#L*
M:68@*"0Q(&5Q("=))RD@>PIP=7-H($!A9&1?=&]?:6YC+"`D,CL*?0IE;'-I
M9B`H)#$@97$@)TTG*2!["F5V86P@(G5S92`D,B(["GT*96QS:68@*"0Q(&5Q
M("=!)RD@>PIU;G-H:69T($!P87)?87)G<RP@)#(["GT*96QS:68@*"0Q(&5Q
M("=/)RD@>PHD;W5T(#T@)#(["GT*96QS:68@*"0Q(&5Q("=B)RD@>PHD8G5N
M9&QE(#T@)W-I=&4G.PI]"F5L<VEF("@D,2!E<2`G0B<I('L*)&)U;F1L92`]
M("=A;&PG.PI]"F5L<VEF("@D,2!E<2`G<2<I('L*)'%U:65T(#T@,3L*?0IE
M;'-I9B`H)#$@97$@)TPG*2!["F]P96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D
M:64@<7%;0V%N)W0@;W!E;B!L;V<@9FEL92`B)#(B.B`D(5T["GT*96QS:68@
M*"0Q(&5Q("=4)RD@>PHD8V%C:&5?;F%M92`]("0R.PI]"G-H:69T*$!!4D=6
M*3L*:68@*&UY("1C;60@/2`D9&ES=%]C;61[)#%]*2!["F1E;&5T92`D14Y6
M>R=005)?5$5-4"=].PII;FET7VEN8R@I.PIR97%U:7)E(%!!4CHZ1&ES=#L*
M)GLB4$%2.CI$:7-T.CHD8VUD(GTH*2!U;FQE<W,@0$%21U8["B9[(E!!4CHZ
M1&ES=#HZ)&-M9")]*"1?*2!F;W(@0$%21U8["F5X:70["GT*?0IU;G-H:69T
M($!)3D,L($!A9&1?=&]?:6YC.PI]"GT*:68@*"1O=70I('L*>PIR97%U:7)E
M($E/.CI&:6QE.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E
M<W0Z.E-(03L*?0IM>2`D<&%R(#T@<VAI9G0H0$%21U8I.PIM>2`D>FEP.PII
M9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@)&9H+"`G/#IR87<G+"`D<&%R
M(&]R(&1I92!Q<5M#86XG="!F:6YD('!A<B!F:6QE("(D<&%R(CH@)"%=.PIB
M;&5S<R@D9F@L("=)3SHZ1FEL92<I.PHD>FEP(#T@07)C:&EV93HZ6FEP+3YN
M97<["B@@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!A<BD@/3T@
M07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*;W(@9&EE('%Q6T5R<F]R(')E861I
M;F<@>FEP(&%R8VAI=F4@(B1P87(B73L*?0IM>2`E;65T85]P87(@/2!D;R![
M"FEF("@D>FEP(&%N9"!M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-151!
M+GEM;"<I*2!["B1M971A(#U^(',O+BI><&%R.B0O+VUS.PHD;65T82`]?B!S
M+UY<4RXJ+R]M<SL*)&UE=&$@/7X@+UX@("A;7CI=*RDZ("@N*RDD+VUG.PI]
M"GT["FEF("AD969I;F5D("1P87(I('L*;W!E;B!M>2`D<&@L("<\.G)A=R<L
M("1P87(@;W(@9&EE('%Q6T-A;B=T(')E860@<&%R(&9I;&4@(B1P87(B.B`D
M(5T["FUY("1B=68["G)E860@)'!H+"`D8G5F+"`T.PID:64@<7%;(B1P87(B
M(&ES(&YO="!A('!A<B!F:6QE72!U;FQE<W,@)&)U9B!E<2`D4$M:25!?34%'
M24,["F-L;W-E("1P:#L*?0I#<F5A=&50871H*"1O=70I(#L*;7D@)&9H(#T@
M24\Z.D9I;&4M/FYE=R@*)&]U="P*24\Z.D9I;&4Z.D]?0U)%050H*2!\($E/
M.CI&:6QE.CI/7U)$5U(H*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL"C`W-S<L
M"BD@;W(@9&EE('%Q6T-A;B=T(&-R96%T92!F:6QE("(D;W5T(CH@)"%=.PHD
M9F@M/F)I;FUO9&4H*3L*<V5E:R!?1D@L(#`L(#`["FUY("1L;V%D97(["FEF
M("AD969I;F5D("1S=&%R=%]O9E]&24Q%7W-E8W1I;VXI('L*<F5A9"!?1D@L
M("1L;V%D97(L("1S=&%R=%]O9E]&24Q%7W-E8W1I;VX["GT@96QS92!["FQO
M8V%L("0O(#T@=6YD968["B1L;V%D97(@/2`\7T9(/CL*?0II9B`H(21%3E9[
M4$%27U9%4D)!5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I
M('L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["E!!4CHZ1FEL=&5R
M.CI0;V13=')I<"T^87!P;'DH7"1L;V%D97(L("0P*3L*?0HD9F@M/G!R:6YT
M*"1L;V%D97(I"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG(&QO861E<B!T;R`B
M)&]U="(Z("0A73L*:68@*"1B=6YD;&4I('L*<F5Q=6ER92!005(Z.DAE879Y
M.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["FEN:71?:6YC*"D[
M"G)E<75I<F5?;6]D=6QE<R@I.PIM>2!`:6YC(#T@9W)E<"![("$O0E-$4$%.
M+R!]"F=R97`@>PHH)&)U;F1L92!N92`G<VET92<I(&]R"B@D7R!N92`D0V]N
M9FEG.CI#;VYF:6=[87)C:&QI8F5X<'T@86YD"B1?(&YE("1#;VYF:6<Z.D-O
M;F9I9WMP<FEV;&EB97AP?2D["GT@0$E.0SL*<WPO*WPO?&<L('-\+R1\?"!F
M;W)E86-H($!I;F,["FUY("5F:6QE<SL*)&9I;&5S>R1??2LK(&9O<B!`1'EN
M84QO861E<CHZ9&Q?<VAA<F5D7V]B:F5C=',L('9A;'5E<R`E24Y#.PIM>2`D
M;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT?3L@("`@("`@("`C
M(%A86"!L:6)?97AT('9S(&1L97AT(#\*;7D@)7=R:71T96X["F9O<F5A8V@@
M;7D@)&ME>2`H<V]R="!K97ES("5F:6QE<RD@>PIM>2`H)&9I;&4L("1N86UE
M*3L*:68@*&1E9FEN960H;7D@)&9C(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H
M97LD:V5Y?2DI('L**"1F:6QE+"`D;F%M92D@/2`H)&ME>2P@)&9C*3L*?0IE
M;'-E('L*9F]R96%C:"!M>2`D9&ER("A`:6YC*2!["FEF("@D:V5Y(#U^(&U\
M7EQ1)&1I<EQ%+R@N*BDD?&DI('L**"1F:6QE+"`D;F%M92D@/2`H)&ME>2P@
M)#$I.PIL87-T.PI]"FEF("@D:V5Y(#U^(&U\7B]L;V%D97(O6UXO72LO*"XJ
M*21\*2!["FEF("AM>2`D<F5F(#T@)$UO9'5L94-A8VAE>R0Q?2D@>PHH)&9I
M;&4L("1N86UE*2`]("@D<F5F+"`D,2D["FQA<W0["GT*:68@*"UF("(D9&ER
M+R0Q(BD@>PHH)&9I;&4L("1N86UE*2`]("@B)&1I<B\D,2(L("0Q*3L*;&%S
M=#L*?0I]"GT*?0IN97AT('5N;&5S<R!D969I;F5D("1N86UE.PIN97AT(&EF
M("1W<FET=&5N>R1N86UE?2LK.PIN97AT(&EF("%R968H)&9I;&4I(&%N9"`D
M9FEL92`]?B`O7"Y<421L:6)?97AT7$4D+VD["F]U=',H<W!R:6YT9BAQ<5M0
M86-K:6YG($9)3$4@(B5S(BXN+ETL(')E9B`D9FEL92`_("1F:6QE+3Y[;F%M
M97T@.B`D9FEL92DI.PIM>2`D8V]N=&5N=#L*:68@*')E9B@D9FEL92DI('L*
M)&-O;G1E;G0@/2`D9FEL92T^>V)U9GT["GT*96QS92!["FQO8V%L("0O(#T@
M=6YD968["F]P96X@;7D@)'1H+"`G/#IR87<G+"`D9FEL92!O<B!D:64@<7%;
M0V%N)W0@<F5A9"`B)&9I;&4B.B`D(5T["B1C;VYT96YT(#T@/"1T:#X["F-L
M;W-E("1T:#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&-O;G1E
M;G0L("(\96UB961D960^+R1N86UE(BD*:68@(21%3E9[4$%27U9%4D)!5$E-
M?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I;'1E
M<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4L
M("1N86UE*3L*?0HD9F@M/G!R:6YT*")&24Q%(BP*<&%C:R@G3B<L(&QE;F=T
M:"@D;F%M92D@*R`Y*2P*<W!R:6YT9B@B)3`X>"\E<R(L($%R8VAI=F4Z.EII
M<#HZ8V]M<'5T94-20S,R*"1C;VYT96YT*2P@)&YA;64I+`IP86-K*"=.)RP@
M;&5N9W1H*"1C;VYT96YT*2DL"B1C;VYT96YT*0IO<B!D:64@<7%;17)R;W(@
M=W)I=&EN9R!E;6)E9&1E9"!&24Q%('1O("(D;W5T(CH@)"%=.PIO=71S*'%Q
M6U=R:71T96X@87,@(B1N86UE(ETI.PI]"GT*:68@*"1Z:7`I('L*)'II<"T^
M=W)I=&54;T9I;&5(86YD;&4H)&9H*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+
M"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG('II<"!P87)T(&]F("(D;W5T(ET[
M"GT*:68@*"1M971A7W!A<GMC;&5A;GTI('L*)&9H+3YP<FEN="@B7#!#3$5!
M3B(I.PI]"F5L<V4@>PII9B`H(61E9FEN960@)&-A8VAE7VYA;64I('L*;7D@
M)&-T>"`]($1I9V5S=#HZ4TA!+3YN97<H,2D["G-E96L@)&9H+"`P+"`P.PHD
M8W1X+3YA9&1F:6QE*"1F:"D["G-E96L@)&9H+"`P+"`R.PHD8V%C:&5?;F%M
M92`]("1C='@M/FAE>&1I9V5S=#L*?0HD8V%C:&5?;F%M92`]('-U8G-T<B`D
M8V%C:&5?;F%M92P@,"P@)&-A8VAE7VYA;65?<VEZ93L*)&-A8VAE7VYA;64@
M+CT@(EPP(B!X("@D8V%C:&5?;F%M95]S:7IE("T@;&5N9W1H("1C86-H95]N
M86UE*3L*)&9H+3YP<FEN="@D8V%C:&5?;F%M92P*(EPP0T%#2$4B*3L*?0IM
M>2`D;V9F<V5T(#T@)&9H+3YT96QL("T@;&5N9W1H*"1L;V%D97(I.PHD9F@M
M/G!R:6YT*'!A8VLH)TXG+"`D;V9F<V5T*2P*)%!!4E]-04=)0RD["B1F:"T^
M8VQO<V4@;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@=')A:6QE<B!O9B`B)&]U
M="(Z("0A73L*8VAM;V0@,#<U-2P@)&]U=#L*97AI=#L*?0I["FQA<W0@=6YL
M97-S(&1E9FEN960@)'-T87)T7W!O<SL*7V9I>%]P<F]G;F%M92@I.PIR97%U
M:7)E(%!!4CL*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PI["G)E
M<75I<F4@1FEL93HZ1FEN9#L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*;7D@
M)&9H(#T@24\Z.D9I;&4M/FYE=SL@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(",@07)C:&EV93HZ6FEP(&]P97)A=&5S(&]N(&%N($E/.CI(86YD;&4*
M)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE('%Q6V9D;W!E
M;B@I(&9A:6QE9#H@)"%=.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@M
M<R!?1D@I.PIM>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@D>FEP+3YR
M96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z
M.EII<#HZ05I?3TLH*2D*;W(@9&EE('%Q6T5R<F]R(')E861I;F<@>FEP(&%R
M8VAI=F4@(B1P<F]G;F%M92)=.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ
M92@V-"`J(#$P,C0I.PIP=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PHD4$%2
M.CI,:6)#86-H97LD<')O9VYA;65](#T@)'II<#L*;W5T<R@B17AT<F%C=&EN
M9R!Z:7`N+BXB*3L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'TI('L@(R!S
M:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A"F9O<F5A8V@@;7D@)&UE;6)E
M<B`H("1Z:7`M/FUE;6)E<G,@*2!["FYE>'0@:68@)&UE;6)E<BT^:7-$:7)E
M8W1O<GD["FUY("1M96UB97)?;F%M92`]("1M96UB97(M/F9I;&5.86UE.PIN
M97AT('5N;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*7@HO/W-H;&EB+PHH/SHD
M0V]N9FEG.CI#;VYF:6=[87)C:&YA;65]+RD_"BA;7B]=*RD*)`I]>#L*;7D@
M)&5X=')A8W1?;F%M92`]("0Q.PIM>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E
M8RT^8V%T9FEL92@D14Y6>U!!4E]414U0?2P@)&5X=')A8W1?;F%M92D["FEF
M("@M9B`D9&5S=%]N86UE("8F("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP<F5S
M<V5D4VEZ92@I*2!["F]U=',H<7%;4VMI<'!I;F<@(B1M96UB97)?;F%M92(@
M<VEN8V4@:70@86QR96%D>2!E>&ES=',@870@(B1D97-T7VYA;64B72D["GT@
M96QS92!["F]U=',H<7%;17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T;R`B
M)&1E<W1?;F%M92(N+BY=*3L**"1M96UB97(M/F5X=')A8W14;T9I;&5.86UE
M9"@D9&5S=%]N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"DI"F]R(&1I
M92!Q<5M%<G)O<B!E>'1R86-T:6YG('II<"!M96UB97(@=&\@(B1D97-T7VYA
M;64B73L*8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X
M(CL*?0I]"GT*?0IU;FQE<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI
M('L*9&EE(#P\("(N(B!U;FQE<W,@0$%21U8["E5S86=E.B`D,"!;("U!;&EB
M+G!A<B!=(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P
M<F]G<F%M+G!L(%T*)#`@6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*
M+@HD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64@/2`D,"`]('-H:69T
M*$!!4D=6*3L*?0IS=6(@0W)E871E4&%T:"!["FUY("@D;F%M92D@/2!`7SL*
M<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*;7D@*"1B87-E;F%M92P@)'!A=&@L
M("1E>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S92@D;F%M92P@*"=<
M+BXJ)RDI.PIR97%U:7)E($9I;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z.FUK<&%T
M:"@D<&%T:"D@=6YL97-S*"UE("1P871H*3L@(R!M:W!A=&@@9&EE<R!W:71H
M(&5R<F]R"GT*<W5B(')E<75I<F5?;6]D=6QE<R!["G)E<75I<F4@;&EB.PIR
M97%U:7)E($1Y;F%,;V%D97(["G)E<75I<F4@:6YT96=E<CL*<F5Q=6ER92!S
M=')I8W0["G)E<75I<F4@=V%R;FEN9W,["G)E<75I<F4@=F%R<SL*<F5Q=6ER
M92!#87)P.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5R<FYO.PIR
M97%U:7)E($5X<&]R=&5R.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CL*<F5Q
M=6ER92!&8VYT;#L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z
M.E-P96,["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@0V]N9FEG.PIR97%U
M:7)E($E/.CI(86YD;&4["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@0V]M
M<')E<W,Z.EIL:6(["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E($1I
M9V5S=#HZ4TA!.PIR97%U:7)E(%!!4CL*<F5Q=6ER92!005(Z.DAE879Y.PIR
M97%U:7)E(%!!4CHZ1&ES=#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R
M:7`["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*<F5Q=6ER
M92!A='1R:6)U=&5S.PIE=F%L('L@<F5Q=6ER92!#=V0@?3L*979A;"![(')E
M<75I<F4@5VEN,S(@?3L*979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T[
M"F5V86P@>R!R97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PIE=F%L
M('L@<F5Q=6ER92!4:64Z.DAA<V@Z.DYA;65D0V%P='5R92!].PIE=F%L('L@
M<F5Q=6ER92!097)L24\[(')E<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*979A
M;"![(')E<75I<F4@=71F."!].PI]"G-U8B!?<V5T7W!A<E]T96UP('L*:68@
M*&1E9FEN960@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^
M("\H+BLI+RD@>PHD<&%R7W1E;7`@/2`D,3L*<F5T=7)N.PI]"F9O<F5A8V@@
M;7D@)'!A=&@@*`HH;6%P("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$
M25(@5$5-4$1)4B!414U0(%1-4"`I*2P*<7<H($,Z7%Q414U0("]T;7`@+B`I
M"BD@>PIN97AT('5N;&5S<R!D969I;F5D("1P871H(&%N9"`M9"`D<&%T:"!A
M;F0@+7<@)'!A=&@["FUY("1U<V5R;F%M93L*;7D@)'!W=6ED.PIE=F%L('LH
M)'!W=6ED*2`](&=E='!W=6ED*"0^*2!I9B!D969I;F5D("0^.WT["FEF("@@
M9&5F:6YE9"@F5VEN,S(Z.DQO9VEN3F%M92D@*2!["B1U<V5R;F%M92`]("97
M:6XS,CHZ3&]G:6Y.86UE.PI]"F5L<VEF("AD969I;F5D("1P=W5I9"D@>PHD
M=7-E<FYA;64@/2`D<'=U:60["GT*96QS92!["B1U<V5R;F%M92`]("1%3E9[
M55-%4DY!345]('Q\("1%3E9[55-%4GT@?'P@)U-94U1%32<["GT*;7D@)'-T
M;7!D:7(@/2`B)'!A=&@D<WES>U]D96QI;7UP87(M(BYU;G!A8VLH(D@J(BP@
M)'5S97)N86UE*3L*;6MD:7(@)'-T;7!D:7(L(#`W-34["FUY("1C86-H95]D
M:7(["FEF("@D14Y6>U!!4E]#3$5!3GTI('L*)&-A8VAE7V1I<B`](")T96UP
M+20D(CL*?0IE;'-E('L*;W!E;B!M>2`D9F@L("(\.G)A=R(L("1P<F]G;F%M
M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)'!R;V=N86UE(CH@)"%=.PII9B`H
M*&UY("1M86=I8U]P;W,@/2!F:6YD7W!A<E]M86=I8R@D9F@I*2`^/2`P*2![
M"G-E96L@)&9H+"`D;6%G:6-?<&]S"BT@)$9)3$5?;V9F<V5T7W-I>F4*+2!L
M96YG=&@H(EPP0T%#2$4B*2P@,#L*;7D@)&)U9CL*<F5A9"`D9F@L("1B=68L
M(&QE;F=T:"@B7#!#04-(12(I.PII9B`H)&)U9B!E<2`B7#!#04-(12(I('L*
M<V5E:R`D9F@L("1M86=I8U]P;W,*+2`D1DE,15]O9F9S971?<VEZ90HM(&QE
M;F=T:"@B7#!#04-(12(I"BT@)&-A8VAE7VYA;65?<VEZ92P@,#L*<F5A9"`D
M9F@L("1B=68L("1C86-H95]N86UE7W-I>F4["B1B=68@/7X@<R]<,"\O9SL*
M)&-A8VAE7V1I<B`](")C86-H92TD8G5F(CL*?0I]"F-L;W-E("1F:#L*?0II
M9B`H(21C86-H95]D:7(I('L*)&-A8VAE7V1I<B`](")T96UP+20D(CL*)$5.
M5GM005)?0TQ%04Y](#T@,3L*?0HD<W1M<&1I<B`N/2`B)'-Y<WM?9&5L:6U]
M)&-A8VAE7V1I<B(["FUK9&ER("1S=&UP9&ER+"`P-S4U.PHD14Y6>U!!4E]4
M14U0?2`]("1S=&UP9&ER.PIL87-T.PI]"B1P87)?=&5M<"`]("0Q(&EF("1%
M3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\["GT*
M<W5B(%]S879E7V%S('L*;7D@*"1N86UE+"`D8V]N=&5N=',L("1M;V1E*2`]
M($!?.PIM>2`D9G5L;&YA;64@/2`B)'!A<E]T96UP+R1N86UE(CL*=6YL97-S
M("@M92`D9G5L;&YA;64I('L*;7D@)'1E;7!N86UE(#T@(B1F=6QL;F%M92XD
M)"(["FUY("1F:#L**&]P96X@)&9H+"`G/CIR87<G+"`D=&5M<&YA;64I"B8F
M("AP<FEN="`D9F@@)&-O;G1E;G1S*0HF)B`H8VQO<V4@)&9H*0IO<B!D:64@
M<7%;17)R;W(@=W)I=&EN9R`B)'1E;7!N86UE(CH@)"%=.PIC:&UO9"`D;6]D
M92P@)'1E;7!N86UE(&EF(&1E9FEN960@)&UO9&4["G)E;F%M92@D=&5M<&YA
M;64L("1F=6QL;F%M92D@;W(@=6YL:6YK*"1T96UP;F%M92D["GT*<F5T=7)N
M("1F=6QL;F%M93L*?0IS=6(@7W-E=%]P<F]G;F%M92!["FEF("AD969I;F5D
M("1%3E9[4$%27U!23T=.04U%?2!A;F0@)$5.5GM005)?4%)/1TY!345](#U^
M("\H+BLI+RD@>PHD<')O9VYA;64@/2`D,3L*?0HD<')O9VYA;64@?'P]("0P
M.PII9B`H)$5.5GM005)?5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.
M5GM005)?5$5-4'TI(#X](#`I('L*)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G
M;F%M92P@<FEN9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`K(#$I.PI]
M"FEF("@A)$5.5GM005)?4%)/1TY!345](&]R(&EN9&5X*"1P<F]G;F%M92P@
M)'-Y<WM?9&5L:6U]*2`^/2`P*2!["FEF("AO<&5N(&UY("1F:"P@)SPG+"`D
M<')O9VYA;64I('L*<F5T=7)N(&EF("US("1F:#L*?0II9B`H+7,@(B1P<F]G
M;F%M921S>7-[7V5X97TB*2!["B1P<F]G;F%M92`N/2`D<WES>U]E>&5].PIR
M971U<FX["GT*?0IF;W)E86-H(&UY("1D:7(@*'-P;&ET("]<421S>7-[<&%T
M:%]S97!]7$4O+"`D14Y6>U!!5$A]*2!["FYE>'0@:68@97AI<W1S("1%3E9[
M4$%27U1%35!](&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%35!].PHD9&ER(#U^
M(',O7%$D<WES>U]D96QI;7U<120O+SL**"@D<')O9VYA;64@/2`B)&1I<B1S
M>7-[7V1E;&EM?21P<F]G;F%M921S>7-[7V5X97TB*2P@;&%S="D*:68@+7,@
M(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64D<WES>U]E>&5](CL**"@D<')O
M9VYA;64@/2`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M92(I+"!L87-T*0II
M9B`M<R`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M92(["GT*?0IS=6(@7V9I
M>%]P<F]G;F%M92!["B0P(#T@)'!R;V=N86UE('Q\/2`D14Y6>U!!4E]04D]'
M3D%-17T["FEF("AI;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@/"`P
M*2!["B1P<F]G;F%M92`]("(N)'-Y<WM?9&5L:6U])'!R;V=N86UE(CL*?0IM
M>2`D<'=D(#T@*&1E9FEN960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T8W=D
M*"D*.B`H*&1E9FEN960@)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W
M9"@I(#H@8'!W9&`I.PIC:&]M<"@D<'=D*3L*)'!R;V=N86UE(#U^(',O7B@_
M/5PN7"X_7%$D<WES>U]D96QI;7U<12DO)'!W9"1S>7-[7V1E;&EM?2\["B1%
M3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M93L*?0IS=6(@7W!A<E]I;FET
M7V5N=B!["FEF("@@)$5.5GM005)?24Y)5$E!3$E:141]*RL@/3T@,2`I('L*
M<F5T=7)N.PI](&5L<V4@>PHD14Y6>U!!4E])3DE424%,25I%1'T@/2`R.PI]
M"F9O<B`H<7<H(%-005=.140@5$5-4"!#3$5!3B!$14)51R!#04-(12!04D]'
M3D%-12`I("D@>PID96QE=&4@)$5.5GLB4$%27R1?(GT["GT*9F]R("AQ=R\@
M5$U01$E2(%1%35`@0TQ%04X@1$5"54<@+RD@>PHD14Y6>R)005)?)%\B?2`]
M("1%3E9[(E!!4E]'3$]"04Q?)%\B?2!I9B!E>&ES=',@)$5.5GLB4$%27T=,
M3T)!3%\D7R)].PI]"FEF("@D14Y6>U!!4E]414U0?2D@>PID96QE=&4@)$5.
M5GM005)?0TQ%04Y].PI]"GT*<W5B(&]U=',@>PIR971U<FX@:68@)'%U:65T
M.PII9B`H)&QO9V9H*2!["G!R:6YT("1L;V=F:"`B0%]<;B(["GT*96QS92![
M"G!R:6YT(")`7UQN(CL*?0I]"G-U8B!I;FET7VEN8R!["G)E<75I<F4@0V]N
M9FEG.PIP=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P("1#;VYF:6<Z.D-O
M;F9I9WLD7WTL('%W*`IA<F-H;&EB97AP('!R:79L:6)E>'`@<VET96%R8VAE
M>'`@<VET96QI8F5X<`IV96YD;W)A<F-H97AP('9E;F1O<FQI8F5X<`HI.PI]
M"G!A8VMA9V4@;6%I;CL*<F5Q=6ER92!005(["G5N<VAI9G0@0$E.0RP@7"90
M05(Z.F9I;F1?<&%R.PI005(M/FEM<&]R="A`<&%R7V%R9W,I.PID:64@<7%;
M<&%R+G!L.B!#86XG="!O<&5N('!E<FP@<V-R:7!T("(D<')O9VYA;64B.B!.
M;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&Y="G5N;&5S<R`M92`D<')O9VYA
M;64["F1O("1P<F]G;F%M93L*0T]213HZ97AI="@D,2D@:68@*"1`(#U^+UY?
M5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`.PI].PHD.CI?7T52
M4D]2(#T@)$`@:68@)$`["GT*0T]213HZ97AI="@D,2D@:68@*"0Z.E]?15)2
M3U(@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)#HZ7U]%4E)/4B!I
M9B`D.CI?7T524D]2.PHQ.PI?7T5.1%]?"@``0T%#2$4``'!E<FQX<VDN8P``
M```````4``````````%Z4@`!>!`!&PP'")`!``!,````'````$"-___&````
M`$(.$(\"0@X8C@-"#B"-!$(.*(P%00XPA@9!#CB#!T0.0`)L"@XX1`XP00XH
M0@X@0@X80@X00@X(20L``````"0```!L````P(W__WL`````00X0@P)'#B`"
M;`H.$$$."$$+``````!,````E````!B.__\W`@```$(.$(\"0@X8C@-"#B"-
M!$(.*(P%00XPA@9$#CB#!T<.8`,5`0H..$$.,$$.*$(.($(.&$(.$$(."$$+
M`````#P```#D````")#__T$!````0@X0C0)"#AB,`T$.((8$00XH@P5'#L`!
M>@H.*$$.($$.&$(.$$(."$,+```````D````)`$``!B1__^!`````$$.$(,"
M2@Z@`0)O"@X000X(00L`````/````$P!``"`D?__R0````!"#A"-`DH.&(P#
M00X@A@1)#BB#!4<.P`@">@H.*$$.($$.&$(.$$(."$,+`````"P```",`0``
M$)+__ZT`````00X0@P)*#J`(`F\*#A!!#@A%"UT*#A!&#@A%"P```!0```"\
M`0``D)+__RH`````1`X080X(`!0```#4`0``J)+__T0`````1`X0>PX(`!0`
M``#L`0``X)+__P,``````````````#P````$`@``V)+__^\!````0@X0C0)*
M#AB,`T$.((8$00XH@P5*#L`)`EP*#BA!#B!!#AA"#A!"#@A&"P`````<````
M1`(``(B4__\B`````$$.$(,"7`X(`````````"0```!D`@``F)3__T0`````
M2PX0@P)8PPX(70X0@P)##@@````````<````C`(``,"4__]<`0```$0.(`,B
M`0H."$H+`````!P```"L`@```);__UD`````1`X@`DH*#@A""P``````%```
M`,P"``!`EO__JP````!'#N`!````-````.0"``#8EO__"@$```!"#A",`DL.
M&(8#00X@@P1'#K"`!`*Q"@X@00X800X00@X(1@L````4````'`,``+"7__\=
M`````$0.$%@."``T````-`,``+B7__^Q`````$(.$(P"00X8A@-)#B"#!$0.
M,`)&"@X@00X800X00@X(1@L``````%0```!L`P``0)C__XT&````0@X0C@)"
M#AB-`TH.((P$00XHA@5!#C"#!D<.@`,#E`(*#C!!#BA!#B!"#AA"#A!"#@A!
M"P.K`0Z(`TL.D`-;#H@#00Z``P`L````Q`,``'B>__]O`@```$$.$(8"00X8
M@P-$#C`#O`$*#AA!#A!!#@A!"P`````T````]`,``+B@__]>`````$$.$(8"
M00X8@P-'#B`"00H.&$$.$$$."$0+1`X81`X000X(`````"0````L!```D(3_
M_^H!````00X0@P)$#D`#B`$*#A!!#@A!"P````!,````5`0``,B@__\,%@``
M`$(.$(\"1@X8C@-"#B"-!$(.*(P%00XPA@9!#CB#!T<.T`4#YQ4*#CA!#C!!
M#BA"#B!"#AA"#A!"#@A!"P```!0```"D!```B+;__U0`````1`X0`D\."&0`
M``"\!```T+;__Z`!````0@X0CP)%#AB.`T4.((T$0@XHC`5$#C"&!D8..(,'
M1PY``F`*#CA!#C!!#BA"#B!"#AA"#A!"#@A'"P+$"@XX00XP00XH0@X@0@X8
M0@X00@X(0@L`````1````"0%```(N/__]0$```!"#A".`D8.&(T#0@X@C`1!
M#BB&!40.,(,&`T8!"@XH1`X@0@X80@X00@X(10L`````````````)````&P%
M``!@?___\`,````.$$8.&$H/"W<(@``_&CLJ,R0B```````````!&P,[:/K_
M_QP````\?___U/___RR#__^4_O__S(?__X3Z__^<B/__U/K__QR)___\^O__
M7(O__TS[__^LC/__C/O__SR-__^T^___#([___3[__^\CO__)/S__^R.__\\
M_/__/(___U3\__],C___;/S__SR1__^L_/__;)'__\S\__^\D?__]/S__QR3
M__\4_?__?)/__S3]__\LE/__3/W__SR5__^$_?__7)7__YS]__\<EO__U/W_
M_ZR<__\L_O__')___US^__^,G___O/[__YRU__\,_____+7__R3___^<M___
MC/___P,`````````"*Q````````"`````````-`%````````%P````````!@
M$D```````!0`````````!P`````````'`````````.@10```````"```````
M``!X``````````D`````````&``````````5````````````````````!@``
M``````!0`D````````L`````````&``````````%`````````%`+0```````
M"@````````"O!````````/7^_V\``````!!````````!`````````"P$````
M`````0`````````\!`````````$`````````3`0````````!`````````%<$
M`````````0````````!A!`````````$`````````;P0````````!````````
M`#,`````````#``````````P&$````````T`````````V%)````````=````
M`````'P$````````\/__;P````#X$$```````/[__V\`````N!%```````#_
M__]O``````$`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````JD``````````````````
M``````````!F&$```````'880```````AAA```````"6&$```````*880```
M````MAA```````#&&$```````-880```````YAA```````#V&$````````89
M0```````%AE````````F&4```````#890```````1AE```````!6&4``````
M`&890```````=AE```````"&&4```````)890```````IAE```````"V&4``
M`````,890```````UAE```````#F&4```````/890```````!AI````````6
M&D```````"8:0```````-AI```````!&&D```````%8:0```````9AI`````
M``!V&D```````(8:0```````EAI```````"F&D```````+8:0```````QAI`
M``````#6&D```````.8:0```````]AI````````&&T```````!8;0```````
M)AM````````V&T```````$8;0```````5AM```````!F&T```````'8;0```
M````AAM```````"6&T```````*8;0```````MAM```````#&&T```````-8;
M0```````YAM```````#V&T````````8<0```````%AQ````````F'$``````
M`#8<0```````Z%)```````````````````I005(N<&T*``````````#X54``
M`````/__________``````````#__________P```````````$=#0SH@."XS
M(%M$<F%G;VY&;'E=(%)E;&5A<V4O,C`Q.2TP,BTR,@`````$````"0````0`
M``!'3E4`9V]L9"`Q+C$V`````"YT97AT`"YG;W0`+F-O;6UE;G0`+F=O="YP
M;'0`+G)E;&$N<&QT`"YI;FET`"YB<W,`+F1T;W)S`"YC=&]R<P`N9'EN<W1R
M`"YE:%]F<F%M95]H9'(`+F=N=2YV97)S:6]N7W(`+FEN=&5R<``N<F5L82YD
M>6X`+F=N=2YV97)S:6]N`"YN;W1E+F=N=2YG;VQD+79E<G-I;VX`+F1Y;G-Y
M;0`N9FEN:0`N9VYU+FAA<V@`+FYO=&4N=&%G`"YE:%]F<F%M90`N=&U?8VQO
M;F5?=&%B;&4`+F1Y;F%M:6,`+G-H<W1R=&%B`"YR;V1A=&$`+F1A=&$`````
M````````````````````````````````````````````````````````````
M``````````````````````````````!F`````0````(```````````)`````
M`````@```````!4````````````````````!````````````````````M```
M``<````"`````````!@"0```````&`(````````X````````````````````
M!````````````````````)P````+`````@````````!0`D```````%`"````
M``````D````````$`````0````@`````````&`````````!!`````P````(`
M````````4`M```````!0"P```````*\$```````````````````!````````
M````````````J@```/;__V\"```````````00````````!````````#X````
M``````,`````````"````````````````````'@```#___]O`@````````#X
M$$```````/@0````````P``````````#``````````(``````````@``````
M``!7````_O__;P(`````````N!%```````"X$0```````#``````````!```
M``$````$````````````````````;@````0````"`````````.@10```````
MZ!$```````!X``````````,`````````"``````````8`````````!X````$
M````0@````````!@$D```````&`2````````T`4````````#````"P````@`
M````````&``````````H`````0````8`````````,!A````````P&```````
M`!,````````````````````$````````````````````(P````$````&````
M`````%`80```````4!@```````#P`P``````````````````$``````````0
M``````````$````!````!@````````!`'$```````$`<````````ES8`````
M`````````````!````````````````````"D`````0````8`````````V%)`
M``````#84@````````X````````````````````$````````````````````
MZP````$````"`````````.A20```````Z%(```````"20```````````````
M````"````````````````````+X````!``!P`@````````"`DT```````("3
M````````E`4```````````````````@```````````````````!)`````0``
M<`(`````````%)E````````4F0```````.P````````````````````$````
M````````````````V`````8````#``````````"J0````````)H`````````
M`@````````0`````````"``````````0``````````<````!`````P``````
M````K$````````"<````````"`````````````````````@`````````````
M```````5`````0````,`````````"*Q````````(G`````````@"````````
M```````````(````````````````````\P````$````#`````````!"N0```
M````$)X````````H````````````````````"````````````````````#H`
M```!`````P`````````XKD```````#B>````````$```````````````````
M``@````````````````````S`````0````,`````````2*Y```````!(G@``
M`````!`````````````````````(````````````````````R`````$````#
M`````````%BN0```````6)X`````````````````````````````"```````
M`````````````"X````(`````P````````!@KD```````%B>````````H0``
M`````````````````"`````````````````````,`````0```#``````````
M``````````!8G@```````"D````````````````````!``````````$`````
M````A0````<`````````````````````````A)X````````<````````````
M````````!````````````````````.$````#````````````````````````
I`*">````````^0````````````````````$`````````````````````
